# ozi-core CHANGELOG
## 1.19.5 (2025-05-14)


### Build system


* build(deps): bump OZI-Project/release from 1.7.4 to 1.7.6

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.7.4 to 1.7.6.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/7b3bc0282c162a771c69e91decca3e3ba792e221...14c90775d0efe9f0f69a914d05cc9319bfc632a0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6b389a9`](https://github.com/OZI-Project/ozi-core/commit/6b389a9c8b3897f67a61b2b52b44538736ac3785))

* build(deps): bump ozi-spec from 0.28.3 to 0.28.4

Bumps [ozi-spec](https://www.oziproject.dev) from 0.28.3 to 0.28.4.


updated-dependencies:
- dependency-name: ozi-spec
  dependency-version: 0.28.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3d0ad5a`](https://github.com/OZI-Project/ozi-core/commit/3d0ad5a86d1d34d4b9c2773b239ac6117a73c85f))

## 1.19.4 (2025-05-14)


### Build system


* build: ozi.wrap updated to 1.41.9 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`283c171`](https://github.com/OZI-Project/ozi-core/commit/283c17179849537cc9425d0d2c0121a8c7368112))

* build(deps): update ozi-build[core,pip,uv] requirement

Updates the requirements on [ozi-build[core,pip,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/2.0.6...2.2.1)


updated-dependencies:
- dependency-name: ozi-build[core,pip,uv]
  dependency-version: 2.2.1
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`fcb394c`](https://github.com/OZI-Project/ozi-core/commit/fcb394ce220b6ded3e4790ae69f1d983c85d0b87))

* build(deps): bump webui2 from 2.5.5 to 2.5.6

Bumps [webui2](https://github.com/webui-dev/python-webui) from 2.5.5 to 2.5.6.
- [Release notes](https://github.com/webui-dev/python-webui/releases)
- [Commits](https://github.com/webui-dev/python-webui/compare/2.5.5...2.5.6)


updated-dependencies:
- dependency-name: webui2
  dependency-version: 2.5.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5151772`](https://github.com/OZI-Project/ozi-core/commit/51517728e01f6e34fd8cafdcff06b338b692013f))

* build(deps): bump ozi-spec from 0.28.1 to 0.28.3

Bumps [ozi-spec](https://www.oziproject.dev) from 0.28.1 to 0.28.3.


updated-dependencies:
- dependency-name: ozi-spec
  dependency-version: 0.28.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e11dc52`](https://github.com/OZI-Project/ozi-core/commit/e11dc5288a4f2d5f1e89f1ed7e0531a3090ac8a0))

* build(deps): bump trove-classifiers from 2025.5.1.12 to 2025.5.9.12

Bumps [trove-classifiers](https://github.com/pypa/trove-classifiers) from 2025.5.1.12 to 2025.5.9.12.
- [Release notes](https://github.com/pypa/trove-classifiers/releases)
- [Commits](https://github.com/pypa/trove-classifiers/compare/2025.5.1.12...2025.5.9.12)


updated-dependencies:
- dependency-name: trove-classifiers
  dependency-version: 2025.5.9.12
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e7437a8`](https://github.com/OZI-Project/ozi-core/commit/e7437a8c59b68ec523cbb15342f4f76ef9ff4ad0))

* build(deps): bump OZI-Project/publish from 1.13.4 to 1.13.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.4 to 1.13.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.13.4...1.13.7)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`01eebae`](https://github.com/OZI-Project/ozi-core/commit/01eebaeb8d284c6d02ac4ee6925311ee918864ac))

* build(deps): bump OZI-Project/checkpoint from 1.7.2 to 1.7.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.7.2...1.7.3)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e1e8c3b`](https://github.com/OZI-Project/ozi-core/commit/e1e8c3bf3fd9509a2328a817ad0e0c49f8778753))

* build(deps): bump OZI-Project/draft from 1.13.2 to 1.13.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.2 to 1.13.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.13.2...1.13.4)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`09f3fb0`](https://github.com/OZI-Project/ozi-core/commit/09f3fb09867d785270e0c91f44f59f72362400ed))

* build(deps): bump OZI-Project/release from 1.6.5 to 1.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.5 to 1.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/36fe15c47185192e9cf5df744a8d1eb679676e22...7b3bc0282c162a771c69e91decca3e3ba792e221)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.7.4
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`7d4ca11`](https://github.com/OZI-Project/ozi-core/commit/7d4ca110af786ca99a76ad89628f82122b96983c))

## 1.19.3 (2025-05-03)


### Bug fixes


* fix: force release
([`863c7e2`](https://github.com/OZI-Project/ozi-core/commit/863c7e2cb54f96e6922269d81f8701ece221b6db))


### Unknown


* :bug: fix main CLI types — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d6a165d`](https://github.com/OZI-Project/ozi-core/commit/d6a165ddca41419445be5109a2d7ea9c27b6788e))

## 1.19.2 (2025-05-03)


### Bug fixes


* fix: ozi main CLI broken entry_point — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`e94ed97`](https://github.com/OZI-Project/ozi-core/commit/e94ed97147f9eb1aacaa7917359b6842a4cdcb04))


### Chores


* chore: fix lint — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`cd06a38`](https://github.com/OZI-Project/ozi-core/commit/cd06a38e895e7907fcdc6c2b5eaa102de4d2f3eb))

## 1.19.1 (2025-05-02)


### Bug fixes


* fix: add enable_uv and enable_cython to test namespace — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`dbcd670`](https://github.com/OZI-Project/ozi-core/commit/dbcd670ae9a713aacc2d4e74afd5d240e2bb8080))


### Build system


* build(deps): bump ozi-templates from 2.24.8 to 2.24.10

Bumps ozi-templates from 2.24.8 to 2.24.10.


updated-dependencies:
- dependency-name: ozi-templates
  dependency-version: 2.24.10
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`aa98932`](https://github.com/OZI-Project/ozi-core/commit/aa98932e44f76a33fa635b1cc62d42434585b4e9))


### Chores


* chore: clean up lint — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`987a0a3`](https://github.com/OZI-Project/ozi-core/commit/987a0a3fd2778ddcc43aa6227828e540b01ed8b9))

* chore: move ``ozi`` main script to core — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`245ab8c`](https://github.com/OZI-Project/ozi-core/commit/245ab8c2d6969a7a25f76e38a1101e3f63ff9bca))

## 1.19.0 (2025-05-02)

## 1.18.4 (2025-04-27)


### Bug fixes


* fix: add check for meson version to meson.load_ast for API 1.8.0 changes — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`97f67b5`](https://github.com/OZI-Project/ozi-core/commit/97f67b51e891b0f5529ba60473945a154f772fff))


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.7.1 to 1.7.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.7.1...1.7.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b770547`](https://github.com/OZI-Project/ozi-core/commit/b770547b08e005b507231195f51f5150ffaebac9))

* build(deps): bump OZI-Project/release from 1.6.4 to 1.6.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.6.4 to 1.6.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0b2ba9981ee9eea47a358c0d70c5b3764a61b88c...36fe15c47185192e9cf5df744a8d1eb679676e22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`70380d3`](https://github.com/OZI-Project/ozi-core/commit/70380d3193ecf7e6a2d0a4d1b1af64d5c427925c))

* build(deps): bump OZI-Project/publish from 1.13.3 to 1.13.4

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.3 to 1.13.4.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.13.3...1.13.4)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`839d9ce`](https://github.com/OZI-Project/ozi-core/commit/839d9cea6bb3ed0fda2e009c080fc858db4afd65))

* build(deps): bump OZI-Project/draft from 1.13.1 to 1.13.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.1 to 1.13.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.13.1...1.13.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f353457`](https://github.com/OZI-Project/ozi-core/commit/f353457bd4d9061e9bb1761803848d5d92db1fa9))

* build(deps): bump ozi-spec from 0.27.3 to 0.28.1

Bumps [ozi-spec](https://www.oziproject.dev) from 0.27.3 to 0.28.1.


updated-dependencies:
- dependency-name: ozi-spec
  dependency-version: 0.28.1
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0b2cad5`](https://github.com/OZI-Project/ozi-core/commit/0b2cad54394d512fb446d32e2737814a38fbf113))

* build(deps): bump trove-classifiers from 2025.4.28.22 to 2025.5.1.12

Bumps [trove-classifiers](https://github.com/pypa/trove-classifiers) from 2025.4.28.22 to 2025.5.1.12.
- [Release notes](https://github.com/pypa/trove-classifiers/releases)
- [Commits](https://github.com/pypa/trove-classifiers/compare/2025.4.28.22...2025.5.1.12)


updated-dependencies:
- dependency-name: trove-classifiers
  dependency-version: 2025.5.1.12
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`11e4d6c`](https://github.com/OZI-Project/ozi-core/commit/11e4d6cf1bb2dcd116c93c584a5feb45aee34fa3))

* build(deps): bump ozi-templates from 2.24.7 to 2.24.8

Bumps ozi-templates from 2.24.7 to 2.24.8.


updated-dependencies:
- dependency-name: ozi-templates
  dependency-version: 2.24.8
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`0a84567`](https://github.com/OZI-Project/ozi-core/commit/0a84567b5e72118bdb587a3b42235eb978219dc4))

* build(deps): bump trove-classifiers from 2025.4.11.15 to 2025.4.28.22

Bumps [trove-classifiers](https://github.com/pypa/trove-classifiers) from 2025.4.11.15 to 2025.4.28.22.
- [Release notes](https://github.com/pypa/trove-classifiers/releases)
- [Commits](https://github.com/pypa/trove-classifiers/compare/2025.4.11.15...2025.4.28.22)


updated-dependencies:
- dependency-name: trove-classifiers
  dependency-version: 2025.4.28.22
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1602e31`](https://github.com/OZI-Project/ozi-core/commit/1602e312ae61e900802d7c2a72f96fad6e55b045))

* build(deps): bump ozi-templates from 2.24.6 to 2.24.7

Bumps ozi-templates from 2.24.6 to 2.24.7.


updated-dependencies:
- dependency-name: ozi-templates
  dependency-version: 2.24.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4f782f5`](https://github.com/OZI-Project/ozi-core/commit/4f782f5bc7ccc178b461156b3b646ff61a7d7abf))

* build(deps): bump ozi-templates from 2.24.4 to 2.24.6

Bumps ozi-templates from 2.24.4 to 2.24.6.


updated-dependencies:
- dependency-name: ozi-templates
  dependency-version: 2.24.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c97db7e`](https://github.com/OZI-Project/ozi-core/commit/c97db7eb825edd4138bcd0f9f4f37a490d80da8f))


### Features


* feat: spec 0.28

build(deps): bump OZI-Project/release from 1.6.4 to 1.6.5
([`ee3cebc`](https://github.com/OZI-Project/ozi-core/commit/ee3cebce600cdcb19dd217e5ca5a37cc3fb02d0b))


### Performance improvements


* perf: OZI 1.39 changes — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`123df86`](https://github.com/OZI-Project/ozi-core/commit/123df867ff91faecbc3675f47385ae4031b56796))

* perf: move ``ozi`` main script to repo — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`a3b129d`](https://github.com/OZI-Project/ozi-core/commit/a3b129d5f1e569f81b5638f3e924e0599ed75634))


### Unknown


* :bug: no cover meson version guarded code — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`a75ccd6`](https://github.com/OZI-Project/ozi-core/commit/a75ccd6f069729d948b0c4df0600ac07d9fa32bf))

* :bug: pin meson<1.9 because we depend on internals of meson — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`cbb2264`](https://github.com/OZI-Project/ozi-core/commit/cbb2264f17acb5c7ddf8edc0b88a3c832a2c0f99))

## 1.18.3 (2025-04-27)


### Bug fixes


* fix: use TAP-Producer~=1.5.17 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4e60bd6`](https://github.com/OZI-Project/ozi-core/commit/4e60bd6f4e51e40ce5906e82b9b785c0ab60786b))


### Build system


* build(deps): bump ozi-spec from 0.27.2 to 0.27.3

Bumps [ozi-spec](https://www.oziproject.dev) from 0.27.2 to 0.27.3.


updated-dependencies:
- dependency-name: ozi-spec
  dependency-version: 0.27.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`eee875d`](https://github.com/OZI-Project/ozi-core/commit/eee875d90bda89ddc3bbe93cbce89c9293b15173))

## 1.18.2 (2025-04-26)


### Bug fixes


* fix: import typing_extensions pre-3.11 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`06b3ff4`](https://github.com/OZI-Project/ozi-core/commit/06b3ff41df85d6352457f2ad4bfa3b02b472d6c4))

* fix: use version_info correctly — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`cc4ed0d`](https://github.com/OZI-Project/ozi-core/commit/cc4ed0dd1009a77cf12cb9427b70d96873154294))

* fix: compatibility for Python 3.10 and below — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d233c9f`](https://github.com/OZI-Project/ozi-core/commit/d233c9f5c94c9c2029d756bcb554a2de1d3781d6))


### Build system


* build(deps): bump ozi-spec from 0.27.1 to 0.27.2

Bumps [ozi-spec](https://www.oziproject.dev) from 0.27.1 to 0.27.2.


updated-dependencies:
- dependency-name: ozi-spec
  dependency-version: 0.27.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9426eb7`](https://github.com/OZI-Project/ozi-core/commit/9426eb70c5896ad9138a7e6075ff95e89af9dc76))

* build(deps): bump ozi-templates from 2.24.3 to 2.24.4

Bumps ozi-templates from 2.24.3 to 2.24.4.


updated-dependencies:
- dependency-name: ozi-templates
  dependency-version: 2.24.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7102bfa`](https://github.com/OZI-Project/ozi-core/commit/7102bfa03fe7f3e7866d6ed1e24f6351c3488786))


### Chores


* chore: move Self import to TYPE_CHECKING block — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`5f450ce`](https://github.com/OZI-Project/ozi-core/commit/5f450ce77af754b5eb1df8a3bcad4683b30146fa))

* chore: run isort — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`797aa53`](https://github.com/OZI-Project/ozi-core/commit/797aa53cc7f8c95f4e539f9c4e57c8dda3a818ad))

* chore: run isort — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`6007222`](https://github.com/OZI-Project/ozi-core/commit/6007222b166e914a6ba54e6f3f461955162a4a7d))

* chore: fix typo in pyproject — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`739a55e`](https://github.com/OZI-Project/ozi-core/commit/739a55e680c46d2725ffd574c3d90bc3e061380d))

## 1.18.1 (2025-04-26)


### Bug fixes


* fix: Update webui root folder — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`759d200`](https://github.com/OZI-Project/ozi-core/commit/759d2005d6276b9dba92f893f21882ae771287e5))

* fix: misused dist .data folder — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`d8156cb`](https://github.com/OZI-Project/ozi-core/commit/d8156cba1ab327c32594c5f4d2f36724192e0142))


### Chores


* chore: update ozi/ui/meson.build — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c28178e`](https://github.com/OZI-Project/ozi-core/commit/c28178ef9fa0dbc7d15dd1c3adf3d1875873252b))

## 1.18.0 (2025-04-25)


### Bug fixes


* fix: update PKG-INFO rendering for ``ozi-fix missing`` — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`20bf4b4`](https://github.com/OZI-Project/ozi-core/commit/20bf4b4c798d77044418867b45e9783f26560d6d))


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.7.0 to 1.7.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.7.0...1.7.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4962662`](https://github.com/OZI-Project/ozi-core/commit/4962662b81e96c26cb318e90224f0500566c30b2))

* build(deps): bump OZI-Project/publish from 1.13.1 to 1.13.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.1 to 1.13.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.13.1...1.13.3)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b393efe`](https://github.com/OZI-Project/ozi-core/commit/b393efe2b2190f824b55d05c4c5a115b147175d9))

* build(deps): bump OZI-Project/release from 1.5.0 to 1.6.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.5.0 to 1.6.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/924761bcd1ad9c77bbc34363118b2cee4334b8a5...0b2ba9981ee9eea47a358c0d70c5b3764a61b88c)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.6.4
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`3f91d17`](https://github.com/OZI-Project/ozi-core/commit/3f91d1777dddd59dd92e37db52a26b5763c9a5f3))

* build(deps): bump step-security/harden-runner from 2.11.1 to 2.12.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.11.1 to 2.12.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c6295a65d1254861815972266d5933fd6e532bdf...0634a2670c59f64b4a01f0f96f84700a4088b9f0)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.12.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`acf874e`](https://github.com/OZI-Project/ozi-core/commit/acf874e0f1f81403c76422f3fec4afd1e017a544))

* build(deps): update packaging requirement from ~=24.1 to ~=25.0

Updates the requirements on [packaging](https://github.com/pypa/packaging) to permit the latest version.
- [Release notes](https://github.com/pypa/packaging/releases)
- [Changelog](https://github.com/pypa/packaging/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pypa/packaging/compare/24.1...25.0)


updated-dependencies:
- dependency-name: packaging
  dependency-version: '25.0'
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`a2b416c`](https://github.com/OZI-Project/ozi-core/commit/a2b416c435dc39ef218c4c8d82f8a5172828484f))

* build(deps): bump ozi-spec from 0.25.0 to 0.27.1

Bumps [ozi-spec](https://www.oziproject.dev) from 0.25.0 to 0.27.1.


updated-dependencies:
- dependency-name: ozi-spec
  dependency-version: 0.27.1
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`eaa4c2e`](https://github.com/OZI-Project/ozi-core/commit/eaa4c2ea9cdae5fbe6141579a3615c96ad8c6d4a))

* build(deps): bump ozi-templates from 2.23.1 to 2.24.3

Bumps ozi-templates from 2.23.1 to 2.24.3.


updated-dependencies:
- dependency-name: ozi-templates
  dependency-version: 2.24.3
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0624879`](https://github.com/OZI-Project/ozi-core/commit/06248797a517c0e641b44a8fd3fa97dd86a16fe0))

* build(deps): update ozi-build[core,uv] requirement

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.13.0...2.0.6)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 2.0.6
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`2a01b7b`](https://github.com/OZI-Project/ozi-core/commit/2a01b7b660b89992e64f6428ab06e6f3f1bfc764))


### Chores


* chore: run black and fix flakes — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`20062cf`](https://github.com/OZI-Project/ozi-core/commit/20062cf3ba18af343477ec77aea6dfc113105a8c))

* chore: add pip extra to OZI.build requirement — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`12b22dc`](https://github.com/OZI-Project/ozi-core/commit/12b22dc32d2c72037cd8ee171aaad4b2b2d47ab1))

* chore: update project metadata for OZI.build 2.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`b1c365e`](https://github.com/OZI-Project/ozi-core/commit/b1c365e88b1039e9635589e1afe6602a9e24b7f0))


### Features


* feat: OZI.build 2.0

build(deps): bump ozi-spec from 0.25.0 to 0.27.1
([`6991816`](https://github.com/OZI-Project/ozi-core/commit/69918161539c293cce3f7f94cb809ded4c8e1709))


### Performance improvements


* perf: move styles and translation data to dist data folder — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`91bd8e5`](https://github.com/OZI-Project/ozi-core/commit/91bd8e5e72535fdbac80a5bf9cc6169dd92350b7))

## 1.17.7 (2025-04-15)


### Bug fixes


* fix: correct dist_requires name in jinja2 env — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`cb2380d`](https://github.com/OZI-Project/ozi-core/commit/cb2380df186430597babb0c47d127eb7193f06e8))

## 1.17.6 (2025-04-14)


### Bug fixes


* fix: blank default text for requires-dist in webui and autocomplete on — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`960d194`](https://github.com/OZI-Project/ozi-core/commit/960d19479ec13a1a06fa75ac483d8bc8c0a4fc91))


### Build system


* build(deps): bump trove-classifiers from 2025.3.19.19 to 2025.4.11.15

Bumps [trove-classifiers](https://github.com/pypa/trove-classifiers) from 2025.3.19.19 to 2025.4.11.15.
- [Release notes](https://github.com/pypa/trove-classifiers/releases)
- [Commits](https://github.com/pypa/trove-classifiers/compare/2025.3.19.19...2025.4.11.15)


updated-dependencies:
- dependency-name: trove-classifiers
  dependency-version: 2025.4.11.15
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ece8a58`](https://github.com/OZI-Project/ozi-core/commit/ece8a58009de9592100cc6bcee8c664037856a43))

## 1.17.5 (2025-04-14)


### Build system


* build: force release — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`452ca23`](https://github.com/OZI-Project/ozi-core/commit/452ca2372abdbffa5b0d446cc8593fb9990a01e6))


### Unknown


* Delete .python-version — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f6a1d62`](https://github.com/OZI-Project/ozi-core/commit/f6a1d62214b925ce5d4b594ecb5a1cc5dc9ecdc2))

## 1.17.4 (2025-04-14)


### Build system


* build: add requires-dist to webui — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`16ef4fc`](https://github.com/OZI-Project/ozi-core/commit/16ef4fc32d0c9449a423089f49417201c8084619))

* build: move ``pypi_package_exists`` to new ``ozi_core.validate`` module — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`4fbf942`](https://github.com/OZI-Project/ozi-core/commit/4fbf94257daa0a4884c633662e931496517a0c4e))


### Chores


* chore: remove unused dotfiles — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`1ef6a20`](https://github.com/OZI-Project/ozi-core/commit/1ef6a2073ddcbca38926f56365c0e2f78fd7354a))

* chore: update OZI wrapfile to 1.38.2 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`36881a8`](https://github.com/OZI-Project/ozi-core/commit/36881a881ff9311b7e5620ab4ff2d0292cf3fbec))

## 1.17.3 (2025-04-09)

## 1.17.2 (2025-04-07)

## 1.17.1 (2025-04-04)

## 1.17.0 (2025-04-03)


### Bug fixes


* fix: add missing translation — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`1fd7cb6`](https://github.com/OZI-Project/ozi-core/commit/1fd7cb6e893c7b509b9fdfb94bafecf15bbe9e7c))

* fix: correct translation mimetype for argparse help text — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`f9754e2`](https://github.com/OZI-Project/ozi-core/commit/f9754e2c568c71618892766e890a38603c057982))


### Build system


* build(deps): bump ozi-templates from 2.23.0 to 2.23.1

Bumps ozi-templates from 2.23.0 to 2.23.1.


updated-dependencies:
- dependency-name: ozi-templates
  dependency-version: 2.23.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bfa8055`](https://github.com/OZI-Project/ozi-core/commit/bfa8055b4509d4ba78bb27b84decab5e53643b37))

* build: remove fonts from web submodule — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`bfed2ff`](https://github.com/OZI-Project/ozi-core/commit/bfed2ffcc5631c1b286116fbf019e9ee70ded993))

* build: use hosted fonts for webui
([`6ccd47e`](https://github.com/OZI-Project/ozi-core/commit/6ccd47e7fef1e4760aea1a761ea7d12b0f99ca63))

* build(deps): bump OZI-Project/checkpoint from 1.6.0 to 1.7.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.6.0 to 1.7.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.6.0...1.7.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5c23f61`](https://github.com/OZI-Project/ozi-core/commit/5c23f6131cab353a0f6c74d3e404055898708353))

* build(deps): bump OZI-Project/publish from 1.13.0 to 1.13.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.13.0...1.13.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`eb56bf1`](https://github.com/OZI-Project/ozi-core/commit/eb56bf155997334f752d66d2f58489c9391b9794))

* build(deps): bump OZI-Project/draft from 1.13.0 to 1.13.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.13.0...1.13.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`08376ec`](https://github.com/OZI-Project/ozi-core/commit/08376ec36293e444b7495c656fe11b67498e626c))

* build(deps): bump OZI-Project/release from 1.4.0 to 1.5.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.4.0 to 1.5.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/bfb9d90fbd2af52d511a9e08306d1b787b8dcfca...924761bcd1ad9c77bbc34363118b2cee4334b8a5)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-version: 1.5.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`59c9ca6`](https://github.com/OZI-Project/ozi-core/commit/59c9ca62a82de5b015f9fdeaa0412ca138f59616))

* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-version: 1.13.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`a195d05`](https://github.com/OZI-Project/ozi-core/commit/a195d053e4cc324c8cac862414550801d49401d6))

* build(deps): bump step-security/harden-runner from 2.11.0 to 2.11.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.11.0 to 2.11.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/4d991eb9b905ef189e4c376166672c3f2f230481...c6295a65d1254861815972266d5933fd6e532bdf)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f4cd959`](https://github.com/OZI-Project/ozi-core/commit/f4cd95914b014833cf7bbbf355cc6db0bda8cc65))

* build: update meson.build fallback_version — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`d8e0145`](https://github.com/OZI-Project/ozi-core/commit/d8e0145453ba6971c6a3bdab4a8bb68bad7e801e))

* build: ozi-templates==2.23 ozi-spec==0.25 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a5778bd`](https://github.com/OZI-Project/ozi-core/commit/a5778bd4c71a6c04ae713f738e71b3bd794e4688))

* build(deps): update niquests requirement from ~=3.13.0 to ~=3.14.0

Updates the requirements on [niquests](https://github.com/jawah/niquests) to permit the latest version.
- [Release notes](https://github.com/jawah/niquests/releases)
- [Changelog](https://github.com/jawah/niquests/blob/main/HISTORY.md)
- [Commits](https://github.com/jawah/niquests/compare/v3.13.0...v3.14.0)


updated-dependencies:
- dependency-name: niquests
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`e89f79a`](https://github.com/OZI-Project/ozi-core/commit/e89f79a42dfca26fb8c2c98bfb83d5a91a38dded))

* build: update ozi-templates==2.22.0 to ozi-templates==2.22.2 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`95226f9`](https://github.com/OZI-Project/ozi-core/commit/95226f90fac64d75289bc9e4476c12497742635f))

* build(deps): bump webui2 from 2.5.3 to 2.5.5

Bumps [webui2](https://github.com/webui-dev/python-webui) from 2.5.3 to 2.5.5.
- [Release notes](https://github.com/webui-dev/python-webui/releases)
- [Commits](https://github.com/webui-dev/python-webui/compare/2.5.3...2.5.5)


updated-dependencies:
- dependency-name: webui2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b751824`](https://github.com/OZI-Project/ozi-core/commit/b751824105fee04f6c9056bed76f901e7b963745))

* build: add reverse-argparse as a dependency — rjdbcm <rjdbcm@outlook.com>
([`002a294`](https://github.com/OZI-Project/ozi-core/commit/002a294b028dcb8ffbb204ce3825d9fffd8a074b))

* build: move fonts — rjdbcm <rjdbcm@outlook.com>
([`49c490f`](https://github.com/OZI-Project/ozi-core/commit/49c490f15c663442e7c021d3e74b6f74067b4e15))


### Chores


* chore: clean up imports — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d1c525e`](https://github.com/OZI-Project/ozi-core/commit/d1c525ebe77cb511815c080832e8be7f37ba408d))

* chore: run isort — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`62757eb`](https://github.com/OZI-Project/ozi-core/commit/62757eb4a24e5514ff18883c28db2636d81d61fb))

* chore: clean up webui logic — rjdbcm <rjdbcm@outlook.com>
([`b3c6d08`](https://github.com/OZI-Project/ozi-core/commit/b3c6d08fbd9191407df6a14c2c36cc0773e67ca9))


### Features


* feat: add webui2 as a full dependency — rjdbcm <rjdbcm@outlook.com>
([`7a04a6e`](https://github.com/OZI-Project/ozi-core/commit/7a04a6e07d8d2149671d9f0a2e35f9dd9fb217b3))


### Unknown


* Create .python-version — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`43da7b6`](https://github.com/OZI-Project/ozi-core/commit/43da7b67e1204fc2cc008f6fab6f039060872b07))

## 1.16.0 (2025-03-21)


### Build system


* build(deps): bump OZI-Project/publish from 1.12.0 to 1.13.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.12.0 to 1.13.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.12.0...1.13.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`2486560`](https://github.com/OZI-Project/ozi-core/commit/2486560a6844c089f5b8e9f2678fc3d80fa60a52))

* build(deps): bump OZI-Project/draft from 1.12.0 to 1.13.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.12.0 to 1.13.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.12.0...1.13.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c84c6b2`](https://github.com/OZI-Project/ozi-core/commit/c84c6b27ec72f55612722b806d79b69b007ba215))

* build(deps): bump OZI-Project/release from 1.3.4 to 1.4.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.4 to 1.4.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/204e7f8af3396d1a4d77afb66ead74b0804ae058...bfb9d90fbd2af52d511a9e08306d1b787b8dcfca)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`39552a5`](https://github.com/OZI-Project/ozi-core/commit/39552a576e6c932df8d896a0d8c7831c9294d9fc))


### Features


* feat: ozi-spec==0.24.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f830f6b`](https://github.com/OZI-Project/ozi-core/commit/f830f6bf3970eb63d356dc9e98cf3e97f024e8d8))

## 1.15.4 (2025-03-17)


### Build system


* build: force patch — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f4ed9b9`](https://github.com/OZI-Project/ozi-core/commit/f4ed9b905b69fad6c596b2093bb9cd0769dd47d9))


### Unknown


* :bug: force patch release — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f058ad4`](https://github.com/OZI-Project/ozi-core/commit/f058ad44d29bb40f1b86cfcad9b933aa48cb3094))

## 1.15.3 (2025-03-16)

## 1.15.2 (2025-03-09)

## 1.15.1 (2025-02-20)

## 1.15.0 (2025-02-20)


### Bug fixes


* fix: remove deprecated home-page metadata requirement — rjdbcm <rjdbcm@outlook.com>
([`5e9d33e`](https://github.com/OZI-Project/ozi-core/commit/5e9d33ed10157c640530102b0ba75b5c0210f367))

* fix: ExactMatch.license_exception_id type casting — rjdbcm <rjdbcm@outlook.com>
([`103144f`](https://github.com/OZI-Project/ozi-core/commit/103144fd23fc8883d6aaa7d2ac4d1a8e61e75ee9))

* fix: pin trove-classifiers to 2025.2.18.16  — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c830122`](https://github.com/OZI-Project/ozi-core/commit/c830122214e5f06f68e5f8163c7dfead5c8d84fc))

* fix: pin spdx-license-list to 3.26.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`e5e888f`](https://github.com/OZI-Project/ozi-core/commit/e5e888fc0ad4e8147001f28046d9d5972c25e5cb))


### Build system


* build(deps): bump trove-classifiers from 2025.3.13.13 to 2025.3.19.19

Bumps [trove-classifiers](https://github.com/pypa/trove-classifiers) from 2025.3.13.13 to 2025.3.19.19.
- [Release notes](https://github.com/pypa/trove-classifiers/releases)
- [Commits](https://github.com/pypa/trove-classifiers/compare/2025.3.13.13...2025.3.19.19)


updated-dependencies:
- dependency-name: trove-classifiers
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d922cde`](https://github.com/OZI-Project/ozi-core/commit/d922cdeaa1f4f88369882501b370cdb7b5edb928))

* build: update dev workflows — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`84ebd67`](https://github.com/OZI-Project/ozi-core/commit/84ebd677527f70c099a724f839b7e09066e9e237))

* build(deps): bump trove-classifiers from 2025.3.3.18 to 2025.3.13.13

Bumps [trove-classifiers](https://github.com/pypa/trove-classifiers) from 2025.3.3.18 to 2025.3.13.13.
- [Release notes](https://github.com/pypa/trove-classifiers/releases)
- [Commits](https://github.com/pypa/trove-classifiers/compare/2025.3.3.18...2025.3.13.13)


updated-dependencies:
- dependency-name: trove-classifiers
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`eb58244`](https://github.com/OZI-Project/ozi-core/commit/eb582449d94df483540bda1cb63fc64df3da5b19))

* build: include submodules in checkpoint — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4f92d7e`](https://github.com/OZI-Project/ozi-core/commit/4f92d7eae4e298457be202aa4cb28988233e2d57))

* build(deps): bump OZI-Project/checkpoint from 1.5.5 to 1.6.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.5 to 1.6.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.5...1.6.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a19c0c4`](https://github.com/OZI-Project/ozi-core/commit/a19c0c4417dc364d6309446b035b8612dfc11344))

* build(deps): bump OZI-Project/release from 1.3.3 to 1.3.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.3 to 1.3.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/ef531325086db519edaf13b95362051f41bb4802...204e7f8af3396d1a4d77afb66ead74b0804ae058)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bed13ab`](https://github.com/OZI-Project/ozi-core/commit/bed13abe2ff34ca8af147551337271bb9b192774))

* build(deps): bump webui2 from 2.5.2 to 2.5.4

Bumps [webui2](https://github.com/webui-dev/python-webui) from 2.5.2 to 2.5.4.
- [Release notes](https://github.com/webui-dev/python-webui/releases)
- [Commits](https://github.com/webui-dev/python-webui/compare/2.5.2...2.5.4)


updated-dependencies:
- dependency-name: webui2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fd021f2`](https://github.com/OZI-Project/ozi-core/commit/fd021f29376315e2bd349a849a71ed645001b496))

* build(deps): bump trove-classifiers from 2025.2.18.16 to 2025.3.3.18

Bumps [trove-classifiers](https://github.com/pypa/trove-classifiers) from 2025.2.18.16 to 2025.3.3.18.
- [Release notes](https://github.com/pypa/trove-classifiers/releases)
- [Commits](https://github.com/pypa/trove-classifiers/compare/2025.2.18.16...2025.3.3.18)


updated-dependencies:
- dependency-name: trove-classifiers
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b5db014`](https://github.com/OZI-Project/ozi-core/commit/b5db0147a2576ccc8958b23b10a3066a526a9180))

* build(deps): bump OZI-Project/draft from 1.11.1 to 1.12.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.11.1 to 1.12.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.11.1...1.12.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`63d88ce`](https://github.com/OZI-Project/ozi-core/commit/63d88cee962c0aa805dd8266f0e91b1faf74a877))

* build(deps): bump OZI-Project/publish from 1.10.1 to 1.12.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.10.1 to 1.12.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.10.1...1.12.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`50ad07f`](https://github.com/OZI-Project/ozi-core/commit/50ad07f177773eb0930f5761001af69457b21df4))

* build(deps): bump ozi-templates from 2.21.0 to 2.22.0

Bumps [ozi-templates](https://github.com/OZI-Project/ozi-templates) from 2.21.0 to 2.22.0.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.21.0...2.22.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4a31295`](https://github.com/OZI-Project/ozi-core/commit/4a31295e0b874726ee0c1d5024471f8d4f4d151b))

* build(deps): bump webui2 from 2.4.5 to 2.5.2

Bumps [webui2](https://github.com/webui-dev/python-webui) from 2.4.5 to 2.5.2.
- [Release notes](https://github.com/webui-dev/python-webui/releases)
- [Commits](https://github.com/webui-dev/python-webui/compare/2.4.5...2.5.2)


updated-dependencies:
- dependency-name: webui2
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c440400`](https://github.com/OZI-Project/ozi-core/commit/c440400b36312fdad322755611d21152ff6eb1ba))

* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`9e2a9eb`](https://github.com/OZI-Project/ozi-core/commit/9e2a9eb200b6d878c30462e19b5b78e8b2a30914))

* build(deps): bump ozi-templates from 2.20.2 to 2.21.0

Bumps [ozi-templates](https://github.com/OZI-Project/ozi-templates) from 2.20.2 to 2.21.0.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/2.21.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.20.2...2.21.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5ca31f8`](https://github.com/OZI-Project/ozi-core/commit/5ca31f8737f78f6a7b172ae3a6257cb4ada3c10d))

* build(deps): bump ozi-spec from 0.22.4 to 0.23.0

Bumps [ozi-spec](https://github.com/OZI-Project/ozi-spec) from 0.22.4 to 0.23.0.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.23.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.22.4...0.23.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d7ca42d`](https://github.com/OZI-Project/ozi-core/commit/d7ca42d04bddb807afe38620f3ef04ba4cce98d7))

* build(deps): bump step-security/harden-runner from 2.10.4 to 2.11.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.4 to 2.11.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/cb605e52c26070c328afc4562f0b4ada7618a84e...4d991eb9b905ef189e4c376166672c3f2f230481)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e71411a`](https://github.com/OZI-Project/ozi-core/commit/e71411a2ba95881c0a60e412839b61094ab2dc5e))


### Chores


* chore: finish translating ozi-new webui preview — rjdbcm <rjdbcm@outlook.com>
([`1f618ee`](https://github.com/OZI-Project/ozi-core/commit/1f618eecbe1dcd9ce7abe72a79f69e163ac645a4))


### Features


* feat: semantic-release 9.20 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`722504b`](https://github.com/OZI-Project/ozi-core/commit/722504bc9b640736e13ec9d0b80096a8dabd823c))


### Unknown


* Create codeql.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1d4f953`](https://github.com/OZI-Project/ozi-core/commit/1d4f953e554ac682462e8b1f420bfe4be02efd8d))

* :rotating_light: run black — rjdbcm <rjdbcm@outlook.com>
([`816d5b6`](https://github.com/OZI-Project/ozi-core/commit/816d5b6fddf2c3c4ff2ab7ab5231d4070563ddcf))

* :bug: remove deprecated test — rjdbcm <rjdbcm@outlook.com>
([`03b3865`](https://github.com/OZI-Project/ozi-core/commit/03b3865d69be37621c4b87bf7797e90d8339a8cb))

* :bug: fix config getters in webui — rjdbcm <rjdbcm@outlook.com>
([`b191734`](https://github.com/OZI-Project/ozi-core/commit/b19173410d8f4eeed63a822a3b063ede890f77dd))

* :rotating_light: fix lint — rjdbcm <rjdbcm@outlook.com>
([`4c64cc1`](https://github.com/OZI-Project/ozi-core/commit/4c64cc177f34d3d66632fd50ebf83c5a78862fd2))

* :rotating_light: fix lint — rjdbcm <rjdbcm@outlook.com>
([`431bf9e`](https://github.com/OZI-Project/ozi-core/commit/431bf9eff92942ae738f03a7d111bbc159279c41))

* :bug: update save button text on language change — rjdbcm <rjdbcm@outlook.com>
([`c0caa02`](https://github.com/OZI-Project/ozi-core/commit/c0caa02f0836aa72819a03dd75eb3df4120cd1ec))

* :hammer: add options configuration save button to webui — rjdbcm <rjdbcm@outlook.com>
([`b1b9142`](https://github.com/OZI-Project/ozi-core/commit/b1b91421613a8756785024720d9e7fc767ca1ba5))

## 1.14.6 (2025-02-18)


### Bug fixes


* fix: add typographic space ``sp`` key to Translation data — rjdbcm <rjdbcm@outlook.com>
([`d8cb498`](https://github.com/OZI-Project/ozi-core/commit/d8cb498b932b700caab32bbd3ce87a3794e231ad))

* fix: webui disclaimer text MIME type — rjdbcm <rjdbcm@outlook.com>
([`3bf9188`](https://github.com/OZI-Project/ozi-core/commit/3bf91887cb77d661ccd51cd75013953ae8c4638c))

## 1.14.5 (2025-02-17)


### Bug fixes


* fix: incorrect word breaks in translations for text/html — rjdbcm <rjdbcm@outlook.com>
([`bce498e`](https://github.com/OZI-Project/ozi-core/commit/bce498e36dc9ee844bc2fadb2f9bf3303b57b162))

## 1.14.4 (2025-02-17)


### Build system


* build: add mime_type and postprocess to Translation — rjdbcm <rjdbcm@outlook.com>
([`5e52e7a`](https://github.com/OZI-Project/ozi-core/commit/5e52e7a3f7bb520b74b27f82803a33c42308eae9))

## 1.14.3 (2025-02-17)


### Bug fixes


* fix: optional dependency name — rjdbcm <rjdbcm@outlook.com>
([`515e6b3`](https://github.com/OZI-Project/ozi-core/commit/515e6b377be964585e7a6d2fc37661e825ab9522))


### Build system


* build(deps): bump ozi-templates from 2.20.1 to 2.20.2

Bumps [ozi-templates](https://github.com/OZI-Project/ozi-templates) from 2.20.1 to 2.20.2.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.20.1...2.20.2)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`be40586`](https://github.com/OZI-Project/ozi-core/commit/be40586b709847eea1b0447c43a73c6a70996ceb))

* build(deps): bump ozi-spec from 0.22.3 to 0.22.4

Bumps [ozi-spec](https://github.com/OZI-Project/ozi-spec) from 0.22.3 to 0.22.4.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.22.4/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.22.3...0.22.4)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`824b8f6`](https://github.com/OZI-Project/ozi-core/commit/824b8f69a3b475e91aeb47c59725ede4288d1351))

* build: add webui interface preview — rjdbcm <rjdbcm@outlook.com>
([`04e4655`](https://github.com/OZI-Project/ozi-core/commit/04e465569794de51f343f83b6fb426dbc021d153))


### Unknown


* Update web.py — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`66c95fc`](https://github.com/OZI-Project/ozi-core/commit/66c95fc20d3589957cb98ba3edf56f22d615890f))

## 1.14.2 (2025-02-12)


### Build system


* build(deps): bump ozi-spec from 0.22.1 to 0.22.3

Bumps [ozi-spec](https://github.com/OZI-Project/ozi-spec) from 0.22.1 to 0.22.3.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.22.3/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.22.1...0.22.3)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a48fb0d`](https://github.com/OZI-Project/ozi-core/commit/a48fb0db3c73a93f02405007266685497b81de6b))

## 1.14.1 (2025-02-12)


### Build system


* build(deps): bump OZI-Project/publish from 1.10.0 to 1.10.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.10.0 to 1.10.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.10.0...1.10.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6d007c5`](https://github.com/OZI-Project/ozi-core/commit/6d007c52d4c59ab555148a09cc91955b7107251e))

* build(deps): bump OZI-Project/draft from 1.11.0 to 1.11.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.11.0 to 1.11.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.11.0...1.11.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5188adf`](https://github.com/OZI-Project/ozi-core/commit/5188adf26ffa240dab72c1b8c8cc0e1f684d11f8))

* build(deps): bump ozi-spec from 0.22.0 to 0.22.1

Bumps [ozi-spec](https://github.com/OZI-Project/ozi-spec) from 0.22.0 to 0.22.1.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.22.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.22.0...0.22.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`332f539`](https://github.com/OZI-Project/ozi-core/commit/332f539e807e6b66b6313bf9183cbed09cfc86dc))

## 1.14.0 (2025-02-12)

## 1.13.1 (2025-01-29)


### Bug fixes


* fix: update extra dependency group names for Metadata 2.3 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`d80d405`](https://github.com/OZI-Project/ozi-core/commit/d80d405f93f7599dc081916eb7074ac41f1927a5))


### Build system


* build(deps): bump OZI-Project/publish from 1.9.3 to 1.10.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.9.3 to 1.10.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.9.3...1.10.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0d15bed`](https://github.com/OZI-Project/ozi-core/commit/0d15bed675936ec54ef7c36bc506ac4da2bf0757))

* build(deps): bump OZI-Project/draft from 1.10.1 to 1.11.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.10.1 to 1.11.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.10.1...1.11.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1a1163f`](https://github.com/OZI-Project/ozi-core/commit/1a1163fdb10b0a997c98e951a505fc2c9267f28a))

* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`5f247a6`](https://github.com/OZI-Project/ozi-core/commit/5f247a6997968c3c2bca0d67a45d904a51a7bec0))

* build(deps): update niquests requirement from ~=3.12.0 to ~=3.13.0

Updates the requirements on [niquests](https://github.com/jawah/niquests) to permit the latest version.
- [Release notes](https://github.com/jawah/niquests/releases)
- [Changelog](https://github.com/jawah/niquests/blob/main/HISTORY.md)
- [Commits](https://github.com/jawah/niquests/compare/v3.12.0...v3.13.0)


updated-dependencies:
- dependency-name: niquests
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`0c63210`](https://github.com/OZI-Project/ozi-core/commit/0c63210e9a54d5f965fda4deb27679683fd4168d))

* build(deps): bump ozi-templates from 2.19.7 to 2.20.1

Bumps [ozi-templates](https://github.com/OZI-Project/ozi-templates) from 2.19.7 to 2.20.1.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.19.7...2.20.1)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b7d2526`](https://github.com/OZI-Project/ozi-core/commit/b7d2526700b42b5c43a4f0533a177306840c93e6))

* build(deps): bump ozi-spec from 0.21.1 to 0.22.0

Bumps [ozi-spec](https://github.com/OZI-Project/ozi-spec) from 0.21.1 to 0.22.0.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.22.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.21.1...0.22.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ee74eec`](https://github.com/OZI-Project/ozi-core/commit/ee74eecb342c2bc49336bc4c37337ae9b43c13be))

* build(deps): bump OZI-Project/release from 1.3.1 to 1.3.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.1 to 1.3.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/5fead75f13134fe16226c4eba87ae80b52876ab0...ef531325086db519edaf13b95362051f41bb4802)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`caf2760`](https://github.com/OZI-Project/ozi-core/commit/caf2760a35f4d225e5c195bf1c3d958aed2b6845))

* build(deps): bump OZI-Project/checkpoint from 1.5.4 to 1.5.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.4 to 1.5.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.4...1.5.5)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`87251d6`](https://github.com/OZI-Project/ozi-core/commit/87251d6e52661587a94089db4261bad2cd1f0bcd))

* build(deps): bump OZI-Project/publish from 1.9.0 to 1.9.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.9.0 to 1.9.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.9.0...1.9.3)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ffd6c30`](https://github.com/OZI-Project/ozi-core/commit/ffd6c30a446ecfa41ba988334a29ceee58d80080))

* build(deps): bump OZI-Project/draft from 1.10.0 to 1.10.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.10.0 to 1.10.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.10.0...1.10.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cabe8b0`](https://github.com/OZI-Project/ozi-core/commit/cabe8b011d1e32840b781252b74a6cc59e52c4d9))

* build(deps): bump ozi-spec from 0.21.0 to 0.21.1

Bumps [ozi-spec](https://github.com/OZI-Project/ozi-spec) from 0.21.0 to 0.21.1.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.21.0...0.21.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`51f637d`](https://github.com/OZI-Project/ozi-core/commit/51f637d4e384340a10fc89b2d5196332b5a45b8e))


### Features


* feat: semantic-release~=9.19.0

build(deps): bump ozi-spec from 0.21.1 to 0.22.0
([`5b42f9f`](https://github.com/OZI-Project/ozi-core/commit/5b42f9f79dc35c34797ca10caf4d47aa16576de1))

## 1.13.0 (2025-01-28)

## 1.12.4 (2025-01-27)

## 1.12.3 (2025-01-27)


### Build system


* build(deps): bump OZI-Project/publish from 1.8.0 to 1.9.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.8.0 to 1.9.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.8.0...1.9.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`cebee0b`](https://github.com/OZI-Project/ozi-core/commit/cebee0bc08b5aa78610c0ea30eccc6552df309fa))

* build(deps): bump OZI-Project/draft from 1.9.0 to 1.10.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.9.0 to 1.10.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.9.0...1.10.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`268f104`](https://github.com/OZI-Project/ozi-core/commit/268f104c7bb5aeda870e29840aa8cab0136a7c05))

* build(deps): bump ozi-spec from 0.20.2 to 0.21.0

Bumps [ozi-spec](https://github.com/OZI-Project/ozi-spec) from 0.20.2 to 0.21.0.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.21.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.20.2...0.21.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`35a19ca`](https://github.com/OZI-Project/ozi-core/commit/35a19ca3bbb6b4d9d692ee4d48f5b151ae96180d))

* build(deps): bump ozi-spec from 0.20.1 to 0.20.2

Bumps [ozi-spec](https://github.com/OZI-Project/ozi-spec) from 0.20.1 to 0.20.2.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.20.2/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.20.1...0.20.2)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`326cd7e`](https://github.com/OZI-Project/ozi-core/commit/326cd7eeaf6673a7c73bb7a543b44973319134cc))

* build(deps): bump ozi-templates from 2.19.6 to 2.19.7

Bumps [ozi-templates](https://github.com/OZI-Project/ozi-templates) from 2.19.6 to 2.19.7.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/2.19.7/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.19.6...2.19.7)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bb2e68e`](https://github.com/OZI-Project/ozi-core/commit/bb2e68e50720cf6e397168b98248de67f6f545c4))

* build(deps): bump pypa/gh-action-pypi-publish from 1.12.3 to 1.12.4

Bumps [pypa/gh-action-pypi-publish](https://github.com/pypa/gh-action-pypi-publish) from 1.12.3 to 1.12.4.
- [Release notes](https://github.com/pypa/gh-action-pypi-publish/releases)
- [Commits](https://github.com/pypa/gh-action-pypi-publish/compare/67339c736fd9354cd4f8cb0b744f2b82a74b5c70...76f52bc884231f62b9a034ebfe128415bbaabdfc)


updated-dependencies:
- dependency-name: pypa/gh-action-pypi-publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6c9ab41`](https://github.com/OZI-Project/ozi-core/commit/6c9ab41790a84b09c5d551fcb61ee1b0c3dd5169))

* build(deps): bump step-security/harden-runner from 2.10.3 to 2.10.4

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.3 to 2.10.4.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c95a14d0e5bab51a9f56296a4eb0e416910cd350...cb605e52c26070c328afc4562f0b4ada7618a84e)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bf10648`](https://github.com/OZI-Project/ozi-core/commit/bf10648cbcfc153dbb274c01d712122afd92afef))

* build: hard pin ozi-templates and ozi-spec for reproducible build support — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`66dfe7d`](https://github.com/OZI-Project/ozi-core/commit/66dfe7d7b4db0365e6925bf3bd1acb707bb1c679))


### Features


* feat: spec v0.21

build(deps): bump OZI-Project/draft from 1.9.0 to 1.10.0
([`67a7aa8`](https://github.com/OZI-Project/ozi-core/commit/67a7aa89764def53984f09b0609d6efdd8c733d9))

## 1.12.2 (2025-01-18)


### Bug fixes


* fix: correct version tag argument to ``update_wrapfile`` — rjdbcm <rjdbcm@outlook.com>
([`0d64ebb`](https://github.com/OZI-Project/ozi-core/commit/0d64ebba966faccb15a0318ec4a382fa548921cb))

## 1.12.1 (2025-01-17)


### Bug fixes


* fix: add translations for update-wrapfile functionality — rjdbcm <rjdbcm@outlook.com>
([`63d57b6`](https://github.com/OZI-Project/ozi-core/commit/63d57b6e4e0fe0ea3fffb2096ce06ddb451facf8))


### Unknown


* :fire: remove locales added to repo in error — rjdbcm <rjdbcm@outlook.com>
([`6fe38ab`](https://github.com/OZI-Project/ozi-core/commit/6fe38ab74501851cd6ecb2a43dd3a70ce346302d))

## 1.12.0 (2025-01-15)

## 1.11.2 (2025-01-13)


### Build system


* build(deps): bump OZI-Project/publish from 1.7.3 to 1.8.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.3 to 1.8.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.3...1.8.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`9cb1cd5`](https://github.com/OZI-Project/ozi-core/commit/9cb1cd5d979dc2a6a4a750e8e96cb65814af404e))

* build(deps): bump OZI-Project/draft from 1.8.0 to 1.9.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.8.0 to 1.9.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.8.0...1.9.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4fae87c`](https://github.com/OZI-Project/ozi-core/commit/4fae87ce3f248812d4546682dd5878e3e43165e5))

* build(deps): bump OZI-Project/checkpoint from 1.5.3 to 1.5.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.3 to 1.5.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.3...1.5.4)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cfaf37b`](https://github.com/OZI-Project/ozi-core/commit/cfaf37bd0dc8d39643ee0851e4271c0f760dce75))

* build(deps): update ozi-spec requirement from ~=0.19.0 to ~=0.20.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.20.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.19.0...0.20.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`ad8962d`](https://github.com/OZI-Project/ozi-core/commit/ad8962d79523b52967b9bc21d852fea1a8b92a4e))

* build: Delete .github/workflows/purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5406131`](https://github.com/OZI-Project/ozi-core/commit/5406131612e0c587ed8aebdfad89eebd5705a73e))

* build(deps): update ozi-spec requirement from ~=0.18.0 to ~=0.19.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.18.0...0.19.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`bd6daa7`](https://github.com/OZI-Project/ozi-core/commit/bd6daa790ecd4c8e89af3407d3e634c66d44f9a8))


### Features


* feat: semantic-release~=9.16

build(deps): bump OZI-Project/publish from 1.7.3 to 1.8.0
([`ec22d8e`](https://github.com/OZI-Project/ozi-core/commit/ec22d8ecc29f528cd5e9c7513e375df3d94f9f96))

## 1.11.1 (2025-01-13)


### Build system


* build(deps): bump OZI-Project/release from 1.3.0 to 1.3.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.3.0 to 1.3.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/c5bb9bd741887d0a330d4b40042b4db4f4f1e3e4...5fead75f13134fe16226c4eba87ae80b52876ab0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9edc622`](https://github.com/OZI-Project/ozi-core/commit/9edc622762c7018d2869b7cd6be3b5f5902162b5))

## 1.11.0 (2025-01-13)


### Bug fixes


* fix: gitignore ozi subproject files — rjdbcm <rjdbcm@outlook.com>
([`07bf2e4`](https://github.com/OZI-Project/ozi-core/commit/07bf2e45385bbd4beca7afeb4623453d6f1020bd))

* fix: add ``--update-wrapfile`` arg to ``ozi-fix`` — rjdbcm <rjdbcm@outlook.com>
([`35f28cd`](https://github.com/OZI-Project/ozi-core/commit/35f28cd86e679431302f5903d05ecc8937e72178))


### Build system


* build(deps): bump OZI-Project/release from 1.2.2 to 1.3.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.2.2 to 1.3.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/e5d307c6fbe79ab1956a4355014194b7f30721ba...c5bb9bd741887d0a330d4b40042b4db4f4f1e3e4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`20ad05b`](https://github.com/OZI-Project/ozi-core/commit/20ad05b9a5757611706acb7a50e3d3b5c64289b6))

* build(deps): bump OZI-Project/release from 1.2.1 to 1.2.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.2.1 to 1.2.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/b716b63d2e71fead7665c1749fd7497f7f147c2e...e5d307c6fbe79ab1956a4355014194b7f30721ba)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`718f6a2`](https://github.com/OZI-Project/ozi-core/commit/718f6a23a186bb4c469370dd7ce0b88de8fee63c))


### Features


* feat: update ozi wrapfile when rendering a new project with ``--update-wrapfile``, defaults to false — rjdbcm <rjdbcm@outlook.com>
([`f42b95d`](https://github.com/OZI-Project/ozi-core/commit/f42b95d73f3166eb27089df820b080c5d2271c4a))

## 1.10.1 (2025-01-08)


### Build system


* build(deps): bump step-security/harden-runner from 2.10.2 to 2.10.3

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.2 to 2.10.3.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0080882f6c36860b6ba35c610c98ce87d4e2f26f...c95a14d0e5bab51a9f56296a4eb0e416910cd350)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e0a4b71`](https://github.com/OZI-Project/ozi-core/commit/e0a4b7140148617ee1f682a0f8a92333e857d6f2))

* build(deps): bump OZI-Project/checkpoint from 1.5.1 to 1.5.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.1 to 1.5.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.1...1.5.3)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`57f3dbd`](https://github.com/OZI-Project/ozi-core/commit/57f3dbde3aaa23b7af9fb9d49572af7bdb4da250))

* build(deps): bump OZI-Project/draft from 1.7.0 to 1.8.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.7.0 to 1.8.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.7.0...1.8.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`88eb305`](https://github.com/OZI-Project/ozi-core/commit/88eb305843a80aff9b2fdf454562bedead506036))

* build(deps): bump OZI-Project/publish from 1.7.2 to 1.7.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.2...1.7.3)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`887f9e8`](https://github.com/OZI-Project/ozi-core/commit/887f9e868bbde3c7d962e3695d3eb79f92806f09))

* build(deps): bump OZI-Project/release from 1.1.2 to 1.2.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.1.2 to 1.2.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0e2db492d3d36479eadc1ba15e509e911816bc39...b716b63d2e71fead7665c1749fd7497f7f147c2e)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`3da115f`](https://github.com/OZI-Project/ozi-core/commit/3da115f5628cdc8f7ad7d97c870a75aab8989f28))

* build(deps): bump OZI-Project/checkpoint from 1.4.0 to 1.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.4.0 to 1.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.4.0...1.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`87b0718`](https://github.com/OZI-Project/ozi-core/commit/87b071892d1c4c4497e42d5398041be4b7d1eaf4))

* build(deps): update trove-classifiers requirement

Updates the requirements on [trove-classifiers](https://github.com/pypa/trove-classifiers) to permit the latest version.
- [Release notes](https://github.com/pypa/trove-classifiers/releases)
- [Commits](https://github.com/pypa/trove-classifiers/compare/2024.7.1...2025.1.6.15)


updated-dependencies:
- dependency-name: trove-classifiers
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`a36d522`](https://github.com/OZI-Project/ozi-core/commit/a36d522d7a740cd2edc308ec142c4bfcb46443ab))

* build(deps): update niquests requirement from ~=3.11.4 to ~=3.12.0

Updates the requirements on [niquests](https://github.com/jawah/niquests) to permit the latest version.
- [Release notes](https://github.com/jawah/niquests/releases)
- [Changelog](https://github.com/jawah/niquests/blob/main/HISTORY.md)
- [Commits](https://github.com/jawah/niquests/compare/v3.11.4...v3.12.0)


updated-dependencies:
- dependency-name: niquests
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`528ea51`](https://github.com/OZI-Project/ozi-core/commit/528ea51734dcbadfda594a3d7e3ca6b6ddf0dbeb))


### Features


* feat: ``ozi.wrap`` now uses a canonical release tarball — rjdbcm <rjdbcm@outlook.com>
([`ce9ddbd`](https://github.com/OZI-Project/ozi-core/commit/ce9ddbd9d3260764dcc306eaa97195323374b168))

## 1.10.0 (2025-01-01)


### Bug fixes


* fix: run isort
([`68b9213`](https://github.com/OZI-Project/ozi-core/commit/68b9213e084553e75d503726d39b22c5932a37ce))


### Build system


* build(deps): add pathvalidate — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`64df958`](https://github.com/OZI-Project/ozi-core/commit/64df9582d5cbbb0acc2afae74313b4a3a283ca47))


### Features


* feat: validate user-provided project targets — rjdbcm <rjdbcm@outlook.com>
([`b4ba010`](https://github.com/OZI-Project/ozi-core/commit/b4ba0103ab743079a0fd891fa78731ddc8a5a913))

## 1.9.1 (2024-12-31)

## 1.9.0 (2024-12-31)


### Bug fixes


* fix: improper passing of kwargs to ``TAP.comment`` — rjdbcm <rjdbcm@outlook.com>
([`14929a8`](https://github.com/OZI-Project/ozi-core/commit/14929a8dde9dc941a02abc8bb8b3fce8ed98f203))


### Build system


* build(deps): update ozi-spec requirement from ~=0.17.1 to ~=0.18.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.17.1...0.18.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`01fdd02`](https://github.com/OZI-Project/ozi-core/commit/01fdd0251813096c124288f4a094dda55279071e))

* build(deps): ozi-templates~=2.19.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8ff31bd`](https://github.com/OZI-Project/ozi-core/commit/8ff31bd5857076cccd5ba491bb65f7a005b041b9))

* build(deps): update ozi-spec requirement from ~=0.16.0 to ~=0.17.1

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.17.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.16.0...0.17.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`a3217c9`](https://github.com/OZI-Project/ozi-core/commit/a3217c9b2fb1ec49dff3f69d2018cda3667574e7))


### Features


* feat: OZI.build 1.10

build(deps): update ozi-spec requirement from ~=0.17.1 to ~=0.18.0
([`4615f53`](https://github.com/OZI-Project/ozi-core/commit/4615f530a0250d22de3549d6568668c12968dad6))

* feat: switch to niquests over requests

requests is no longer actively updated. — rjdbcm <rjdbcm@outlook.com>
([`c69a3b6`](https://github.com/OZI-Project/ozi-core/commit/c69a3b6c191656a6dcfeba1b6de1eed8b93bcf62))

## 1.8.0 (2024-12-20)


### Bug fixes


* fix: OZI.build 1.8.2 metadata — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`be03a26`](https://github.com/OZI-Project/ozi-core/commit/be03a269d89fd4b745306c571742faf1fa9ac7cc))


### Build system


* build(deps): update ozi-templates requirement from ~=2.18.0 to ~=2.19.0

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.18.0...2.19.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`12c34ff`](https://github.com/OZI-Project/ozi-core/commit/12c34ff3a33ac1679a25a45a27a32ba6363afd92))

* build(deps): bump OZI-Project/draft from 1.6.3 to 1.7.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.3 to 1.7.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.3...1.7.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`bc50ec8`](https://github.com/OZI-Project/ozi-core/commit/bc50ec88c4210dad0b7c885ddafccb3f47e8e93d))

* build(deps): bump OZI-Project/publish from 1.7.1 to 1.7.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.1...1.7.2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d282dd7`](https://github.com/OZI-Project/ozi-core/commit/d282dd7b0ab23289c11b941d941a0b0446704e17))

* build(deps): update ozi-templates requirement from ~=2.17.0 to ~=2.18.0

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/2.18.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.17.0...2.18.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`197c0e0`](https://github.com/OZI-Project/ozi-core/commit/197c0e03555717e02fa24eb8732faeec920e399e))

* build(deps): update ozi-spec requirement from ~=0.15.3 to ~=0.16.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.15.3...0.16.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`31cbcd2`](https://github.com/OZI-Project/ozi-core/commit/31cbcd26f8168d6029e2d08c20c4b068223978c5))


### Features


* feat: spec v0.16

build(deps): update ozi-spec requirement from ~=0.15.3 to ~=0.16.0
([`60b9967`](https://github.com/OZI-Project/ozi-core/commit/60b99679dad7aa7db4060cf7f50aa02e855ab71c))

## 1.7.0 (2024-12-17)


### Features


* feat: spec v0.15 pypa/gh-action-pypi-publish 1.12 support

1.6.0
([`e53c742`](https://github.com/OZI-Project/ozi-core/commit/e53c7425f34ea3b93cc19c732afbfefacb41e40d))


### Unknown


* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`db612f4`](https://github.com/OZI-Project/ozi-core/commit/db612f4e0f8de07d5f74b64ccf92deb4587197db))

* Update purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`d19cdc1`](https://github.com/OZI-Project/ozi-core/commit/d19cdc1b468bb7e35698ba42e4c7f524635e34a8))

* Create purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8c878ce`](https://github.com/OZI-Project/ozi-core/commit/8c878ce00cfa9c5d0c8808ce47be324c4a7c67ad))

## 1.6.0 (2024-12-09)


### Build system


* build(deps): bump OZI-Project/draft from 1.5.0 to 1.6.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.5.0 to 1.6.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.5.0...1.6.3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4edd0fc`](https://github.com/OZI-Project/ozi-core/commit/4edd0fc5e6f5f02a27cd04de9f4a073bc5fa7791))

* build(deps): bump OZI-Project/release from 1.0.5 to 1.1.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.5 to 1.1.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1a3cb28a9a9d51fa8e333740a8b863c0f23ab3da...0e2db492d3d36479eadc1ba15e509e911816bc39)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4305517`](https://github.com/OZI-Project/ozi-core/commit/430551715c9f737b79bdec22beb5133d8bf9df5b))

* build(deps): bump OZI-Project/publish from 1.5.0 to 1.7.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.5.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.5.0...1.7.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`903ecb4`](https://github.com/OZI-Project/ozi-core/commit/903ecb4d62b048546e852f065e9cfd244d24169f))

* build(deps): update ozi-templates requirement from ~=2.16.0 to ~=2.17.0

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.16.0...2.17.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`95c9bac`](https://github.com/OZI-Project/ozi-core/commit/95c9bac49a698ca606df3b313ba9fe0d93b26971))

* build(deps): update ozi-spec requirement from ~=0.14.1 to ~=0.15.3

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.14.1...0.15.3)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`f17d51c`](https://github.com/OZI-Project/ozi-core/commit/f17d51c53975ce881d9a7708ff488f30310a5635))

* build(deps): bump OZI-Project/checkpoint from 1.2.1 to 1.4.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.2.1 to 1.4.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.2.1...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f318116`](https://github.com/OZI-Project/ozi-core/commit/f318116bf280196bc48901373c63a86f2681bc4d))

* build: ozi-spec~=0.14.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`386d73a`](https://github.com/OZI-Project/ozi-core/commit/386d73a459e0a93d414c4697e8225baed2c20e7f))

* build(deps): update ozi-spec requirement from ~=0.13.1 to ~=0.14.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.14.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.13.1...0.14.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`855a5d1`](https://github.com/OZI-Project/ozi-core/commit/855a5d136d91772de9b96cdc79fc4ef014d77590))


### Features


* feat: semantic-release~=9.15

build(deps): update ozi-spec requirement from ~=0.13.1 to ~=0.14.0
([`e2c3a80`](https://github.com/OZI-Project/ozi-core/commit/e2c3a80a91c22d5a31bf88f05ca052901592f875))


### Unknown


* Update ozi.yml endpoint and publish workflow — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`494c4c8`](https://github.com/OZI-Project/ozi-core/commit/494c4c8820695751a2a0cc717dd195da11939307))

* Update dev.yml endpoints — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1b184bf`](https://github.com/OZI-Project/ozi-core/commit/1b184bfd32d4f4aa7f6afa960c7abb2846526f0d))

* Update .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4425276`](https://github.com/OZI-Project/ozi-core/commit/4425276c3f74b89fdf44558ed7dd502e34966c20))

* Update .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`112c18f`](https://github.com/OZI-Project/ozi-core/commit/112c18f3e80c4926eb62ec62739bd78c7ecc8580))

* Create .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`7a712de`](https://github.com/OZI-Project/ozi-core/commit/7a712dec23a15a73b79044a02433ada4cbe3a906))

## 1.5.23 (2024-12-06)


### Build system


* build: ozi-spec 0.13.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`766c02d`](https://github.com/OZI-Project/ozi-core/commit/766c02db94585f17c21848a96346e7ea6a562131))


### Unknown


* Update ozi.wrap — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f044748`](https://github.com/OZI-Project/ozi-core/commit/f044748fd5bc0b63c7a383b1428685d002d6710d))

## 1.5.22 (2024-11-30)


### Build system


* build(deps): update ozi-spec requirement from ~=0.12.1 to ~=0.13.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.13.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.12.1...0.13.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`29ad933`](https://github.com/OZI-Project/ozi-core/commit/29ad933832a72d03ed6fe95ebaf38309f9af3296))

* build(deps): update ozi-templates requirement from ~=2.15.1 to ~=2.16.0

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/2.16.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.15.1...2.16.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`4a263c0`](https://github.com/OZI-Project/ozi-core/commit/4a263c0a59d66c0f100a24a87b0d20f1a3af97a2))

## 1.5.21 (2024-11-25)


### Bug fixes


* fix: ozi-templates~=2.15.1 — rjdbcm <rjdbcm@outlook.com>
([`cfbfe96`](https://github.com/OZI-Project/ozi-core/commit/cfbfe96e762ebf82a1d32afaf2a7a3141d3cff61))

* fix: restore TAP.end() call for ozi-fix missing — rjdbcm <rjdbcm@outlook.com>
([`c069a83`](https://github.com/OZI-Project/ozi-core/commit/c069a83186616f997fe493219b9b0014d1d84a31))

## 1.5.20 (2024-11-25)


### Bug fixes


* fix: backtrack further on ozi-templates dep — rjdbcm <rjdbcm@outlook.com>
([`d19568e`](https://github.com/OZI-Project/ozi-core/commit/d19568ea86843f57b174d8b7234d684018b057e7))

## 1.5.19 (2024-11-22)


### Performance improvements


* perf: include logger name in log format — rjdbcm <rjdbcm@outlook.com>
([`e36fc63`](https://github.com/OZI-Project/ozi-core/commit/e36fc6384af67f9e38001ba210b907c8f2fe6fd2))

* perf: cache ``meson.build`` ast — rjdbcm <rjdbcm@outlook.com>
([`bb61ef7`](https://github.com/OZI-Project/ozi-core/commit/bb61ef72f84c075023ac49e1cde1814143a9b8d3))

## 1.5.18 (2024-11-22)


### Bug fixes


* fix: ``--add`` and ``--remove`` no longer nested list — rjdbcm <rjdbcm@outlook.com>
([`2a26622`](https://github.com/OZI-Project/ozi-core/commit/2a26622c387c8876548dc292bfbe8a064be0a7af))

## 1.5.17 (2024-11-21)


### Bug fixes


* fix: manual release trigger — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`b612da4`](https://github.com/OZI-Project/ozi-core/commit/b612da457ee32b3a3994a3f5ad86ec502daee101))


### Unknown


* :bug: fix fail to load config if it doesnt exist — rjdbcm <rjdbcm@outlook.com>
([`359e53d`](https://github.com/OZI-Project/ozi-core/commit/359e53dec001921b1a12a870d64351ec7f10c667))

## 1.5.16 (2024-11-21)


### Bug fixes


* fix: add ``uninstall_user_files`` help translation, fix logging in ``_i18n`` — rjdbcm <rjdbcm@outlook.com>
([`cccfe39`](https://github.com/OZI-Project/ozi-core/commit/cccfe39351b21ed0684296f2b439343d4ffd2d45))

## 1.5.15 (2024-11-21)


### Build system


* build(deps): upgrade from TAP-Producer~=1.4.1 to TAP-Producer~=1.5.0 — rjdbcm <rjdbcm@outlook.com>
([`a773c73`](https://github.com/OZI-Project/ozi-core/commit/a773c73e3eef78976a671714f5f4ffbfb2528a9e))

## 1.5.14 (2024-11-20)


### Bug fixes


* fix: log paths are correctly typed, add an ``uninstall_user_files`` action — rjdbcm <rjdbcm@outlook.com>
([`9651fda`](https://github.com/OZI-Project/ozi-core/commit/9651fdac9c18d90452eab70eb0755a7b1bc6e84d))


### Unknown


* lint — rjdbcm <rjdbcm@outlook.com>
([`4fc82ab`](https://github.com/OZI-Project/ozi-core/commit/4fc82ab395730915458fa4de0d0ad3a99fd7c981))

## 1.5.13 (2024-11-20)


### Bug fixes


* fix: remove overly productive logger call
([`00564de`](https://github.com/OZI-Project/ozi-core/commit/00564de88396ecbf843e8e8e0adb608b4058a087))

## 1.5.12 (2024-11-20)


### Bug fixes


* fix: no more duplicate log entries, log file extension corrected to ``.json`` — rjdbcm <rjdbcm@outlook.com>
([`65c1ccf`](https://github.com/OZI-Project/ozi-core/commit/65c1ccf2574248aba9b53f796ab54fe7efa7618a))

## 1.5.11 (2024-11-19)


### Bug fixes


* fix: properly filter log records during pytest exec — rjdbcm <rjdbcm@outlook.com>
([`c06cc64`](https://github.com/OZI-Project/ozi-core/commit/c06cc647484002b09bdc2a980a141709f42d0c0c))


### Build system


* build(deps): bump step-security/harden-runner from 2.10.1 to 2.10.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.1 to 2.10.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/91182cccc01eb5e619899d80e4e971d6181294a7...0080882f6c36860b6ba35c610c98ce87d4e2f26f)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9c0d9c9`](https://github.com/OZI-Project/ozi-core/commit/9c0d9c9dc4435158e9ea11ba4db4ca38b21a07e3))

## 1.5.10 (2024-11-19)


### Bug fixes


* fix: ozi-fix correctly appends to add and remove args — rjdbcm <rjdbcm@outlook.com>
([`ca1f9fc`](https://github.com/OZI-Project/ozi-core/commit/ca1f9fc9ca72d53cd1983ce8aa4589340c513046))

* fix: add _logging.pyi — rjdbcm <rjdbcm@outlook.com>
([`18e36dd`](https://github.com/OZI-Project/ozi-core/commit/18e36dde8bc757dd9dfee09c30baccbe9e89224f))

* fix: add some sparse logs for developer debug — rjdbcm <rjdbcm@outlook.com>
([`cbc0375`](https://github.com/OZI-Project/ozi-core/commit/cbc03758605fd3ed2a9d297f7482696c8c7af9df))

* fix: suppress FileNotFoundError in required_files check — rjdbcm <rjdbcm@outlook.com>
([`98c52cb`](https://github.com/OZI-Project/ozi-core/commit/98c52cb25f3281328f14ee74259f10ed9988599f))

* fix: move nested function _check_package_exists — rjdbcm <rjdbcm@outlook.com>
([`ff590bf`](https://github.com/OZI-Project/ozi-core/commit/ff590bfa5ce0b45706b47b4180bdeb0b24a51bb9))


### Performance improvements


* perf: alert user that ci_user was not set but skip in testing — rjdbcm <rjdbcm@outlook.com>
([`376c6cf`](https://github.com/OZI-Project/ozi-core/commit/376c6cf6d0e24cfc35b7185ce38e7175990d257d))


### Unknown


* increase lint timeout — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`bf8c22b`](https://github.com/OZI-Project/ozi-core/commit/bf8c22bf862f3f41fab8a72226962aeb1d1f919c))

* isort — rjdbcm <rjdbcm@outlook.com>
([`cf37f6d`](https://github.com/OZI-Project/ozi-core/commit/cf37f6d30f8decfce8415be64a03929e6c86ed97))

## 1.5.9 (2024-11-18)


### Build system


* build(deps): ozi-spec~=0.12.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8d59810`](https://github.com/OZI-Project/ozi-core/commit/8d598109c29e7e57a016f7273afa771815097ea6))

* build(deps): update ozi-templates requirement from ~=2.14.0 to ~=2.15.0

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.14.0...2.15.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`43ffac1`](https://github.com/OZI-Project/ozi-core/commit/43ffac13c1182878b39d4885c3531db1f0612d91))

## 1.5.8 (2024-11-17)


### Bug fixes


* fix: read user config on ozi-fix interactive prompt __init__ — rjdbcm <rjdbcm@outlook.com>
([`c925813`](https://github.com/OZI-Project/ozi-core/commit/c9258138c14260679f717cb55b262faca6dc7cbf))

## 1.5.7 (2024-11-17)


### Bug fixes


* fix: setting pretty in interactive mode ozi-fix works — rjdbcm <rjdbcm@outlook.com>
([`01182ec`](https://github.com/OZI-Project/ozi-core/commit/01182ec339fda7a124c1e41192423b092aa149e7))

## 1.5.6 (2024-11-17)


### Bug fixes


* fix: pretty mode setting works in ozi-fix interactive — rjdbcm <rjdbcm@outlook.com>
([`0da3aa4`](https://github.com/OZI-Project/ozi-core/commit/0da3aa452cfb49d7b0f57dfa9e4cb7fe5debc9b1))

## 1.5.5 (2024-11-17)


### Bug fixes


* fix: update deadline for flaky test — rjdbcm <rjdbcm@outlook.com>
([`f5f7b68`](https://github.com/OZI-Project/ozi-core/commit/f5f7b68e215a0de8f06403644398ed6591ab4fef))

* fix: correctly loop fix mode interactive dialog — rjdbcm <rjdbcm@outlook.com>
([`bea79f0`](https://github.com/OZI-Project/ozi-core/commit/bea79f005be28a32c9c5b7b9bd346d78a903e8c2))

* fix: remove generated locales file used for testing — rjdbcm <rjdbcm@outlook.com>
([`bd646fd`](https://github.com/OZI-Project/ozi-core/commit/bd646fdb518e2a973d4a11718822e936a29d8823))

* fix: translate fix mode dialog ok button — rjdbcm <rjdbcm@outlook.com>
([`a20fd2a`](https://github.com/OZI-Project/ozi-core/commit/a20fd2a8c4a1f51820a4be76f190c05a8139260f))

## 1.5.4 (2024-11-17)


### Bug fixes


* fix: use the user-defined language locale in interactive prompts — rjdbcm <rjdbcm@outlook.com>
([`c691377`](https://github.com/OZI-Project/ozi-core/commit/c691377662f361acb9e4b0af0a4df69a9aa604b7))

## 1.5.3 (2024-11-17)


### Bug fixes


* fix: add options menu to set ozi-fix options and menu language — rjdbcm <rjdbcm@outlook.com>
([`c1d5206`](https://github.com/OZI-Project/ozi-core/commit/c1d520689c07470fb3830106948871ae61991ff0))


### Unknown


* run lint — rjdbcm <rjdbcm@outlook.com>
([`d6f07e8`](https://github.com/OZI-Project/ozi-core/commit/d6f07e8914c7331ca176da326ce01aaba5495f38))

## 1.5.2 (2024-11-17)


### Bug fixes


* fix: add translated string for options save dialog
([`fb43c37`](https://github.com/OZI-Project/ozi-core/commit/fb43c378b4de29e165642756222bd67c51fe008a))

## 1.5.1 (2024-11-17)


### Bug fixes


* fix: remove __init__ from dataclasses in stubs — rjdbcm <rjdbcm@outlook.com>
([`49f1889`](https://github.com/OZI-Project/ozi-core/commit/49f1889b70ca831c08f9e15e5fa84a9300bb1a49))

* fix: run black — rjdbcm <rjdbcm@outlook.com>
([`f8098bd`](https://github.com/OZI-Project/ozi-core/commit/f8098bdd10387fba138b4d8c818dcadc741370b3))

* fix: clean up stubs — rjdbcm <rjdbcm@outlook.com>
([`0ec4271`](https://github.com/OZI-Project/ozi-core/commit/0ec42713adbeead137520dd74d3069af7b6af542))


### Performance improvements


* perf: add config.yml file for user-defined defaults in interactive CLI — rjdbcm <rjdbcm@outlook.com>
([`0dbfdd5`](https://github.com/OZI-Project/ozi-core/commit/0dbfdd5ea895254a378f19ac289f61de623241e3))

## 1.5.0 (2024-11-15)


### Build system


* build(deps): bump OZI-Project/release from 1.0.4 to 1.0.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.4 to 1.0.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/74350f112641257ed33f06f83c3e6fc7ae92059b...1a3cb28a9a9d51fa8e333740a8b863c0f23ab3da)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8d7d27c`](https://github.com/OZI-Project/ozi-core/commit/8d7d27ced4955f2fa02a78c22c5b43c72630227e))

* build(deps): bump OZI-Project/draft from 1.4.0 to 1.5.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.0 to 1.5.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.4.0...1.5.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5f54cbf`](https://github.com/OZI-Project/ozi-core/commit/5f54cbf521937e973130ce289518768fc0235815))

* build(deps): bump OZI-Project/publish from 1.4.1 to 1.5.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.1 to 1.5.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.4.1...1.5.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a6b118d`](https://github.com/OZI-Project/ozi-core/commit/a6b118d93840e36b0ec29ae9da9fa3672a62f45b))

* build(deps): bump OZI-Project/checkpoint from 1.1.3 to 1.2.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.3 to 1.2.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.1.3...1.2.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d9bea4e`](https://github.com/OZI-Project/ozi-core/commit/d9bea4e2a6a7f09d07519d24ab25d97cfbb64d61))

* build(deps): update ozi-templates requirement from ~=2.13.15 to ~=2.14.0

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/2.14.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.13.15...2.14.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`e0ea88e`](https://github.com/OZI-Project/ozi-core/commit/e0ea88ea423613534a303b1cdd26ec61477b450e))


### Features


* feat: spec v0.12 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`04c270c`](https://github.com/OZI-Project/ozi-core/commit/04c270c2b4c03b7976352d460097ce89c84c9629))

## 1.4.17 (2024-11-15)


### Build system


* build(deps): update ozi-spec requirement from ~=0.11.7 to ~=0.12.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.12.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.11.7...0.12.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`352f207`](https://github.com/OZI-Project/ozi-core/commit/352f2074489dcc66a605c898f7d1e2eb8f3dd30a))

* build(deps): ozi-spec~=0.11.7 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8a00811`](https://github.com/OZI-Project/ozi-core/commit/8a008116bcac9831e43a4a7e8d0e07901b408bf0))

## 1.4.16 (2024-11-11)


### Build system


* build(deps): ozi-templates~=2.13.15 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`fce5480`](https://github.com/OZI-Project/ozi-core/commit/fce5480cbba4a5907613425d100696423fae0dc0))

* build: fix tox paths for cross-platform — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`3025862`](https://github.com/OZI-Project/ozi-core/commit/3025862a16456129d6a8826b8c658c5613afbaad))

* build(deps): bump OZI-Project/checkpoint from 1.1.2 to 1.1.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.2 to 1.1.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.1.2...1.1.3)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f75506d`](https://github.com/OZI-Project/ozi-core/commit/f75506d5eeb81335f2b9025cbf4b02193e52e7f6))

* build(deps): bump OZI-Project/checkpoint from 1.1.1 to 1.1.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.1 to 1.1.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.1.1...1.1.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`74a7c20`](https://github.com/OZI-Project/ozi-core/commit/74a7c207c31541ab5cc24117b710c9ebd0422240))

* build:  create dev.yml checkpoints for CI — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8c3b9a5`](https://github.com/OZI-Project/ozi-core/commit/8c3b9a546b222806b5862653487dd68603b80edc))

## 1.4.15 (2024-11-11)


### Performance improvements


* perf(ozi-fix): add input validation — rjdbcm <rjdbcm@outlook.com>
([`364eb12`](https://github.com/OZI-Project/ozi-core/commit/364eb12b585d5ce077bb8fc03b6c7bcf1e8e085d))

## 1.4.14 (2024-11-10)


### Build system


* build(deps): ozi-templates~=2.13.14 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c5c5cc3`](https://github.com/OZI-Project/ozi-core/commit/c5c5cc3bb80b50ed4b2233f0a11d82020cde289f))

## 1.4.13 (2024-11-10)


### Bug fixes


* fix: render.build_child ignores errors on existing directory — rjdbcm <rjdbcm@outlook.com>
([`1049e9a`](https://github.com/OZI-Project/ozi-core/commit/1049e9ae6d31cf51a7f8c0000779ee82f2eb02cf))

* fix: revert to OZI-Project/publish 1.4.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a64f4f5`](https://github.com/OZI-Project/ozi-core/commit/a64f4f56db2ee423a2198e142837f3c78bbeadde))


### Build system


* build(deps): ozi-templates~=2.13.13 — rjdbcm <rjdbcm@outlook.com>
([`c493822`](https://github.com/OZI-Project/ozi-core/commit/c493822352e08bc0a36dc10afff8fca6f1ffc88a))


### Performance improvements


* perf: meson rewriter compatibility improvements — rjdbcm <rjdbcm@outlook.com>
([`8a96beb`](https://github.com/OZI-Project/ozi-core/commit/8a96beb0a06fbc6ca257b4164634b78e6460fa19))

## 1.4.12 (2024-11-09)


### Build system


* build(deps): bump OZI-Project/publish from 1.4.1 to 1.4.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.1 to 1.4.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.4.1...1.4.2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b00567d`](https://github.com/OZI-Project/ozi-core/commit/b00567d6cd6ed16c34751610849272affd066cdd))


### Performance improvements


* perf(ozi-fix interactive): ability to input files and folders — rjdbcm <rjdbcm@outlook.com>
([`c832796`](https://github.com/OZI-Project/ozi-core/commit/c832796b96e5bc3668a6ff5863b95e4fcf3e2245))

## 1.4.11 (2024-11-08)


### Performance improvements


* perf(ozi-fix): unroll ``meson.build`` subdir call loops before outputting rewriter commands — rjdbcm <rjdbcm@outlook.com>
([`5f71978`](https://github.com/OZI-Project/ozi-core/commit/5f719785602b18b674729f514125caf6e7f3f007))

## 1.4.10 (2024-11-07)


### Performance improvements


* perf(ozi-fix interactive): automatic meson rewriter invocation — rjdbcm <rjdbcm@outlook.com>
([`ea6a4be`](https://github.com/OZI-Project/ozi-core/commit/ea6a4be3b535036f27d77c543a8d09ea15c1446a))

* perf: OZI 1.24 wrapfile — rjdbcm <rjdbcm@outlook.com>
([`7cf1644`](https://github.com/OZI-Project/ozi-core/commit/7cf164432c391cfe0c2f9fbae40e00f43b8d447c))


### Unknown


* lint: run isort — rjdbcm <rjdbcm@outlook.com>
([`7118775`](https://github.com/OZI-Project/ozi-core/commit/7118775bcb2d5ac238450b42904b8bce53d44e0d))

## 1.4.9 (2024-11-07)


### Bug fixes


* fix: ozi-templates~=2.13.11 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`cbea6d8`](https://github.com/OZI-Project/ozi-core/commit/cbea6d8c8f6105fe9750932cfde8dd286293fd31))

* fix: ozi-spec 0.11.5 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`43feb7b`](https://github.com/OZI-Project/ozi-core/commit/43feb7bf31fdd8fb065cb9b4272ed5be202b4a90))


### Build system


* build(deps): bump OZI-Project/publish from 1.4.0 to 1.4.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.4.0...1.4.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4b23f06`](https://github.com/OZI-Project/ozi-core/commit/4b23f0655ceb2fcd0052d90aedb12757a6e485ad))

## 1.4.8 (2024-11-04)


### Bug fixes


* fix: correct ui submodule install path — rjdbcm <rjdbcm@outlook.com>
([`f9f0969`](https://github.com/OZI-Project/ozi-core/commit/f9f0969a4e9b897f1f9c223f8ab316bd651e69c1))

## 1.4.7 (2024-11-04)


### Performance improvements


* perf: add translated strings to ozi-fix interactive — rjdbcm <rjdbcm@outlook.com>
([`ac1f0e6`](https://github.com/OZI-Project/ozi-core/commit/ac1f0e63c0711e45548a304f517b00c2e5799b92))

* perf: fix.build_definition.walk function now a generator — rjdbcm <rjdbcm@outlook.com>
([`86385ad`](https://github.com/OZI-Project/ozi-core/commit/86385ad0af04a619a8d8152545fa6fd4dd8cf39d))

* perf: refactor UI to add an ozi-fix interactive mode — rjdbcm <rjdbcm@outlook.com>
([`980831d`](https://github.com/OZI-Project/ozi-core/commit/980831d967ce3067bec5c8a8e5e3b24632990c7d))


### Unknown


* :hammer: refactor UI to add an ozi-fix interactive mode — rjdbcm <rjdbcm@outlook.com>
([`4734d92`](https://github.com/OZI-Project/ozi-core/commit/4734d9279656cbbceff075c385e7f3e951e48817))

## 1.4.6 (2024-11-01)


### Build system


* build(endpoints): add sigstore urls to allow list — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`7912ae8`](https://github.com/OZI-Project/ozi-core/commit/7912ae89c67d1a0ff76dea4da81241e7e96d7c8e))

* build(deps): ozi-templates~=2.13.8 — rjdbcm <rjdbcm@outlook.com>
([`142da4a`](https://github.com/OZI-Project/ozi-core/commit/142da4a639b7286611a5340da2673ec7fd28da80))


### Performance improvements


* perf: test that harden-runner blocks render — rjdbcm <rjdbcm@outlook.com>
([`32544ad`](https://github.com/OZI-Project/ozi-core/commit/32544ad35f7e759e188c8e6a9b1d44c0b7c7cd22))

## 1.4.5 (2024-10-29)


### Build system


* build(deps): ozi-spec~=0.11.4 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`7102f08`](https://github.com/OZI-Project/ozi-core/commit/7102f08f234d4db97bbb48a977b644c59e3106b6))

## 1.4.4 (2024-10-28)


### Build system


* build(deps): ozi-spec~=0.11.2 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`e74e7b9`](https://github.com/OZI-Project/ozi-core/commit/e74e7b9b7f61d6fbc24706f8b3bca0f8e2bc7381))

## 1.4.3 (2024-10-28)


### Bug fixes


* fix: only use multiline input_dialog for copyright header — rjdbcm <rjdbcm@outlook.com>
([`df89a10`](https://github.com/OZI-Project/ozi-core/commit/df89a10bedf867264e29cb6803017f3e532827d7))


### Build system


* build(deps): update ozi-templates requirement from ~=2.12.5 to ~=2.13.0

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/2.13.0/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.12.5...2.13.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`719ccea`](https://github.com/OZI-Project/ozi-core/commit/719ccea81f271427e318ce8bc7e32f094b97a44c))

* build(deps): bump OZI-Project/checkpoint from 1.0.2 to 1.1.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.2 to 1.1.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.2...1.1.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8d85692`](https://github.com/OZI-Project/ozi-core/commit/8d8569240db9a9df177e3efc6b6fc55d6b3eabc4))

## 1.4.2 (2024-10-25)


### Build system


* build: update fallback version to 1.24 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`465dd5d`](https://github.com/OZI-Project/ozi-core/commit/465dd5d767799c7669835f1fafd8a2688ded89e4))

## 1.4.1 (2024-10-25)


### Bug fixes


* fix: ozi-spec~=0.11.1

OZI-Project/checkpoint 1.1.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5763687`](https://github.com/OZI-Project/ozi-core/commit/5763687061a3bb7027defa61ccd2873622233350))

## 1.4.0 (2024-10-25)


### Bug fixes


* fix: generate locales at build time — rjdbcm <rjdbcm@outlook.com>
([`83e3c40`](https://github.com/OZI-Project/ozi-core/commit/83e3c401f35d644de406db9668e1265301096fe7))

* fix: generate locales at build time — rjdbcm <rjdbcm@outlook.com>
([`b481dc7`](https://github.com/OZI-Project/ozi-core/commit/b481dc7201c145cd5edf90ee0e911169dac47a5c))


### Features


* feat: ozi-spec~=0.11.0 — rjdbcm <rjdbcm@outlook.com>
([`f78d693`](https://github.com/OZI-Project/ozi-core/commit/f78d69391998f795de987595680bb6d22a68a8fb))

## 1.3.7 (2024-10-24)


### Bug fixes


* fix: update fallback version to 1.23 — rjdbcm <rjdbcm@outlook.com>
([`1de7c4a`](https://github.com/OZI-Project/ozi-core/commit/1de7c4a8855b647b3844896f9af4632467382002))


### Performance improvements


* perf: TAP-Producer~=1.4.1 and remove undocumented dependency on typing_extensions <3.11 — rjdbcm <rjdbcm@outlook.com>
([`8bba66c`](https://github.com/OZI-Project/ozi-core/commit/8bba66c96f0ba008cb878f4a29ccd2a007ba8342))

## 1.3.6 (2024-10-19)


### Bug fixes


* fix: dont print TAP plan after dumping json — rjdbcm <rjdbcm@outlook.com>
([`bc68a76`](https://github.com/OZI-Project/ozi-core/commit/bc68a76cf05c3f9e16f9c2ac63ebb611858ac686))

## 1.3.5 (2024-10-19)


### Bug fixes


* fix(ozi-fix): correctly suppress TAP output — rjdbcm <rjdbcm@outlook.com>
([`ac53fe7`](https://github.com/OZI-Project/ozi-core/commit/ac53fe73f1e9ca74b894300fdd2a7b54feb65395))

## 1.3.4 (2024-10-18)


### Build system


* build(deps): bump OZI-Project/draft from 1.3.0 to 1.4.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.3.0...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ea0e895`](https://github.com/OZI-Project/ozi-core/commit/ea0e8958ccea055c5dcf880df7088774a9c8015c))

* build(deps): bump OZI-Project/publish from 1.3.0 to 1.4.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.3.0...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`9a5d860`](https://github.com/OZI-Project/ozi-core/commit/9a5d86011ef5fbb434787264a98d2452fcc68556))

* build(deps): ozi-spec~=0.10.8 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`81e9f2e`](https://github.com/OZI-Project/ozi-core/commit/81e9f2efa683ea5ee74ce54d75229209c33e3882))

* build(deps): TAP-Producer~=1.3.2 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`fcf69fd`](https://github.com/OZI-Project/ozi-core/commit/fcf69fd07da3f053ce74d506c4c185fb82d5b531))

## 1.3.3 (2024-10-18)


### Bug fixes


* fix: correct API use for TAP-Producer 1.3 — rjdbcm <rjdbcm@outlook.com>
([`2207a29`](https://github.com/OZI-Project/ozi-core/commit/2207a29982b2b592249f625772e76a981a2f5cfe))


### Build system


* build(deps): TAP-Producer~=1.3.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`b58e477`](https://github.com/OZI-Project/ozi-core/commit/b58e4777804e4082a279d05560ba5db16e6c01fd))

## 1.3.2 (2024-10-16)


### Bug fixes


* fix: correct TAP output, README symlink

TAP-Producer 1.2.0 — rjdbcm <rjdbcm@outlook.com>
([`127c7b2`](https://github.com/OZI-Project/ozi-core/commit/127c7b2c3f121ecadbe78d92390c65ff179d5bed))

## 1.3.1 (2024-10-14)


### Bug fixes


* fix: ozi-spec~=0.10.7

OZI version 1.23 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`339625f`](https://github.com/OZI-Project/ozi-core/commit/339625f76951eea5d24bac09597f75d60787f4b7))

## 1.3.0 (2024-10-14)


### Build system


* build(deps): bump OZI-Project/release from 1.0.3 to 1.0.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.3 to 1.0.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/d764d82aa0900effc1590b0281ff35d67be592fd...74350f112641257ed33f06f83c3e6fc7ae92059b)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bbe3ff6`](https://github.com/OZI-Project/ozi-core/commit/bbe3ff6fde69878c187f3c4c34d1ddcddc82ca73))

* build(deps): bump OZI-Project/checkpoint from 1.0.1 to 1.0.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.1 to 1.0.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.1...1.0.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`0d78a34`](https://github.com/OZI-Project/ozi-core/commit/0d78a34c18ebea6870f4202151f8971f5c8be10b))

* build(deps): bump OZI-Project/publish from 1.1.0 to 1.3.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.1.0 to 1.3.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.1.0...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f81c824`](https://github.com/OZI-Project/ozi-core/commit/f81c824ff7684aa2ad8c4b6b5ec79c293f80e920))

* build(deps): bump OZI-Project/draft from 1.1.0 to 1.3.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.1.0 to 1.3.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.1.0...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5349a29`](https://github.com/OZI-Project/ozi-core/commit/5349a299185b033eb907ac6f66282ed5e011d6f6))


### Features


* feat: semantic-release 9.10 and complete typing stubs — rjdbcm <rjdbcm@outlook.com>
([`bd1b317`](https://github.com/OZI-Project/ozi-core/commit/bd1b3172683cb81e4329422d99fd9103d10c0782))

* feat: semantic-release 9.11 and complete typing stubs — rjdbcm <rjdbcm@outlook.com>
([`ca12220`](https://github.com/OZI-Project/ozi-core/commit/ca12220749c93f6f7dbbf43c2dfa7d1e32c80843))

## 1.2.17 (2024-10-14)


### Performance improvements


* perf: correct stub typechecking — rjdbcm <rjdbcm@outlook.com>
([`b6d7656`](https://github.com/OZI-Project/ozi-core/commit/b6d7656c945767619173f2f6026b8a97dafbf825))

* perf: add stubfiles
([`743c9e8`](https://github.com/OZI-Project/ozi-core/commit/743c9e8c06d4272f5b05be8bff368fd016109a14))

* perf: add stubfiles — rjdbcm <rjdbcm@outlook.com>
([`d97b1fb`](https://github.com/OZI-Project/ozi-core/commit/d97b1fb43ea808dcac5e1c7bfd53697cb0a24a85))

## 1.2.16 (2024-10-13)


### Bug fixes


* fix: temporarily disable automated build time locale generation — rjdbcm <rjdbcm@outlook.com>
([`efa70de`](https://github.com/OZI-Project/ozi-core/commit/efa70de173e94ead61e2fddeaf5b17853e8e3a13))


### Performance improvements


* perf: better copyright header parsing — rjdbcm <rjdbcm@outlook.com>
([`5a63060`](https://github.com/OZI-Project/ozi-core/commit/5a63060b3b8796672f9388d173c980c47b64ed60))

* perf: refresh locales at build time, fix some typos — rjdbcm <rjdbcm@outlook.com>
([`ebad03f`](https://github.com/OZI-Project/ozi-core/commit/ebad03ff899ede4aad6159a96fabd547a2784b99))


### Unknown


* :globe_with_meridians:(ozi-fix): internationalize the TAP output — rjdbcm <rjdbcm@outlook.com>
([`4465a05`](https://github.com/OZI-Project/ozi-core/commit/4465a05bfa66e3ac24944f5b48c3b85ce0f8f6b5))

* :globe_with_meridians:(ozi-new): internationalize the TAP output — rjdbcm <rjdbcm@outlook.com>
([`02437ee`](https://github.com/OZI-Project/ozi-core/commit/02437eea3aa02198c736380080627fd2d0f52d24))

* :hammer: refactor interactive dialogs
([`13a2846`](https://github.com/OZI-Project/ozi-core/commit/13a284682ff53b5eef0632b4b68606e2d58a5cd8))

## 1.2.15 (2024-10-10)


### Bug fixes


* fix: default to english locale in case of unsupported language — rjdbcm <rjdbcm@outlook.com>
([`d41ed78`](https://github.com/OZI-Project/ozi-core/commit/d41ed783972f6f64d14014a783e52b14fc85d130))

* fix: incorrect/missing translation asset keys
([`9b34997`](https://github.com/OZI-Project/ozi-core/commit/9b349970c4d4d6031473e184e9fbf5953ee93a61))

## 1.2.14 (2024-10-09)


### Bug fixes


* fix: missing help text for target — rjdbcm <rjdbcm@outlook.com>
([`a3a8b7b`](https://github.com/OZI-Project/ozi-core/commit/a3a8b7b8443b2c8b07d66dd2db01954984b52674))

## 1.2.13 (2024-10-09)

## 1.2.12 (2024-10-09)

## 1.2.11 (2024-10-08)


### Bug fixes


* fix: hard locale file for the time being — rjdbcm <rjdbcm@outlook.com>
([`e7285e8`](https://github.com/OZI-Project/ozi-core/commit/e7285e884e12b49b78121851a1cd10ebfb8f28ea))

* fix: install PyYAML during build — rjdbcm <rjdbcm@outlook.com>
([`8b7c5f9`](https://github.com/OZI-Project/ozi-core/commit/8b7c5f9dbf0b9cec467c0ff17e1fd744f18caabd))

* fix: lint complaints — rjdbcm <rjdbcm@outlook.com>
([`eb2fd82`](https://github.com/OZI-Project/ozi-core/commit/eb2fd8259c59771a478e186791bf218d15569ff4))

* fix: type locale data — rjdbcm <rjdbcm@outlook.com>
([`a55512d`](https://github.com/OZI-Project/ozi-core/commit/a55512d5af8750e96cdc71752d1f3a94a282a736))

* fix: locales are now pre-compiled - fixes issue with docs display — rjdbcm <rjdbcm@outlook.com>
([`5ee0203`](https://github.com/OZI-Project/ozi-core/commit/5ee020302e254ea48a342c279632ddd245d68c61))


### Performance improvements


* perf: ozi-spec~=0.10.2 semantic-release v9.9 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`d1c8b55`](https://github.com/OZI-Project/ozi-core/commit/d1c8b555de58bd3c851b2f4dcd786b24c7eddb86))


### Unknown


* Update LICENSE.txt to include exception text — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`3f49071`](https://github.com/OZI-Project/ozi-core/commit/3f490717aa4c96818ac3a333b2288059eae28a54))

## 1.2.10 (2024-10-08)


### Bug fixes


* fix: add no cover to import guard — rjdbcm <rjdbcm@outlook.com>
([`efc9a16`](https://github.com/OZI-Project/ozi-core/commit/efc9a163057a61fd4026f191fab683a98c95715d))


### Performance improvements


* perf: add import guard for curses on win32
([`5816226`](https://github.com/OZI-Project/ozi-core/commit/58162268fbd74992e91726a41d24020e5f61ef36))

* perf: add import guard for curses on win32 — rjdbcm <rjdbcm@outlook.com>
([`52d1a3f`](https://github.com/OZI-Project/ozi-core/commit/52d1a3f3810e125466f8d7e5581b5008658b791b))

* perf: chinese UI title more readable — rjdbcm <rjdbcm@outlook.com>
([`089a5df`](https://github.com/OZI-Project/ozi-core/commit/089a5dfcff7d8ce0e6db7bc4022219b88b2e766a))

* perf(ozi-new): import guard in case of win32 — rjdbcm <rjdbcm@outlook.com>
([`155eda0`](https://github.com/OZI-Project/ozi-core/commit/155eda09e02bb63dd720ababf257934037b528df))

* perf: set raw terminal mode for interactive prompt — rjdbcm <rjdbcm@outlook.com>
([`1a37bc7`](https://github.com/OZI-Project/ozi-core/commit/1a37bc7b30d56ef3f15936c8a26d1b59caf5385c))

* perf: flexible input dialog width and height based on default — rjdbcm <rjdbcm@outlook.com>
([`e9ae813`](https://github.com/OZI-Project/ozi-core/commit/e9ae813e861fb4144c7bf1a75ff98e1bb17c707e))

## 1.2.9 (2024-10-07)


### Bug fixes


* fix: add License-File dialog — rjdbcm <rjdbcm@outlook.com>
([`aed82bc`](https://github.com/OZI-Project/ozi-core/commit/aed82bcda0749919824ca22a3644b5e5b27e1821))


### Performance improvements


* perf: remove LicenseFileValidator — rjdbcm <rjdbcm@outlook.com>
([`c446f4e`](https://github.com/OZI-Project/ozi-core/commit/c446f4e2f74c0a6e0c193f7831f5846647bb54bd))

* perf: better Chinese UX — rjdbcm <rjdbcm@outlook.com>
([`bf64f1b`](https://github.com/OZI-Project/ozi-core/commit/bf64f1bed7b74c9e1134b46f22450b14c378761a))

* perf: fix missing title translation — rjdbcm <rjdbcm@outlook.com>
([`db02db5`](https://github.com/OZI-Project/ozi-core/commit/db02db51da361172966eae038095abec3c19abfa))

## 1.2.8 (2024-10-07)


### Performance improvements


* perf: clean up interactive prompt implementation — rjdbcm <rjdbcm@outlook.com>
([`6a1a86b`](https://github.com/OZI-Project/ozi-core/commit/6a1a86b3addc391b103556d7281379451242253a))

## 1.2.7 (2024-10-06)


### Bug fixes


* fix: empty translation values coerced to str — rjdbcm <rjdbcm@outlook.com>
([`f1f14eb`](https://github.com/OZI-Project/ozi-core/commit/f1f14eb1daedd21d156faaed0826d4ffe1e09d1d))

## 1.2.6 (2024-10-06)


### Bug fixes


* fix: add some pyright ignores — rjdbcm <rjdbcm@outlook.com>
([`a80f17f`](https://github.com/OZI-Project/ozi-core/commit/a80f17fa5ca11dfc91eeb778fc3dd8ac2832e930))


### Performance improvements


* perf: more translations for the CLI — rjdbcm <rjdbcm@outlook.com>
([`95ea579`](https://github.com/OZI-Project/ozi-core/commit/95ea579211f14e9ac1a4378af396ec3ccdae67a1))

## 1.2.5 (2024-10-05)


### Bug fixes


* fix: remove 3.10 checkpoint pending deprecation — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`69f1ef9`](https://github.com/OZI-Project/ozi-core/commit/69f1ef9f0164eaeb04f6a393b719c6a2fdcc7876))

* fix: erroneous call to TAP version after interactive session — rjdbcm <rjdbcm@outlook.com>
([`a03be5f`](https://github.com/OZI-Project/ozi-core/commit/a03be5f76fa04146ed6947f932724741bc38aa1c))


### Build system


* build(deps): bump OZI-Project/release from 1.0.2 to 1.0.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.2 to 1.0.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/48fdd720e637c583fe162559ebe23d5ae0e24f8f...d764d82aa0900effc1590b0281ff35d67be592fd)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a1289cd`](https://github.com/OZI-Project/ozi-core/commit/a1289cd42100f470ba19b771c5cd71aba7365f31))

* build(deps): bump OZI-Project/release from 1.0.1 to 1.0.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.1 to 1.0.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/3015ae773cba4b74f1ff7afb55ad1e6324d56f51...48fdd720e637c583fe162559ebe23d5ae0e24f8f)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ae1a78e`](https://github.com/OZI-Project/ozi-core/commit/ae1a78e1ef385b5372f2277633d1a145685bba89))

* build(deps): bump OZI-Project/draft from 1.0.2 to 1.1.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.2 to 1.1.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.0.2...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`73b379f`](https://github.com/OZI-Project/ozi-core/commit/73b379f795806c415964043c61048da774d2b11d))

* build(deps): bump OZI-Project/publish from 1.0.2 to 1.1.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.2 to 1.1.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.0.2...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`3f17126`](https://github.com/OZI-Project/ozi-core/commit/3f17126874c680222dccb15388eb5845655b8cc6))


### Performance improvements


* perf: run lint — rjdbcm <rjdbcm@outlook.com>
([`6ecc276`](https://github.com/OZI-Project/ozi-core/commit/6ecc276a5405e7bb31614c9d142801060a748b3c))

* perf: finish i18n for CLI — rjdbcm <rjdbcm@outlook.com>
([`fe74ffc`](https://github.com/OZI-Project/ozi-core/commit/fe74ffcceb3fd3f627754b8b6178e629e6da58eb))

* perf: internationalize the ``ozi-fix`` interface and ``ozi-new`` validator error messages — rjdbcm <rjdbcm@outlook.com>
([`5eff10a`](https://github.com/OZI-Project/ozi-core/commit/5eff10ac440b2e95d325f0d08d809824dbf2b85f))

* perf: complete internationalization of ``ozi-new`` CLI — rjdbcm <rjdbcm@outlook.com>
([`182839b`](https://github.com/OZI-Project/ozi-core/commit/182839b5665ee21ffbbbc8a21bb26c0e4c2203aa))

* perf: add a License-File prompt and validator — rjdbcm <rjdbcm@outlook.com>
([`976f02e`](https://github.com/OZI-Project/ozi-core/commit/976f02e9f468af8f7190c311f18623519c2eaad9))

## 1.2.4 (2024-10-02)


### Bug fixes


* fix: typos in i18n — rjdbcm <rjdbcm@outlook.com>
([`4927181`](https://github.com/OZI-Project/ozi-core/commit/492718139b3ace0a8ebe360e6b813185bb35d044))


### Build system


* build(deps): bump OZI-Project/release from 1.0.0 to 1.0.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/98248899bb8b235e3198105f080093ea5b9751d8...3015ae773cba4b74f1ff7afb55ad1e6324d56f51)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a882caa`](https://github.com/OZI-Project/ozi-core/commit/a882caab8127afb2cbd057337a5188e107d6880e))

* build(deps): bump OZI-Project/checkpoint from 1.0.0 to 1.0.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`027e98b`](https://github.com/OZI-Project/ozi-core/commit/027e98b58c3fa2d7cf90fb902b9aa5807b20e25a))

* build(deps): bump OZI-Project/publish from 1.0.0 to 1.0.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.0 to 1.0.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.0.0...1.0.2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6f90e4f`](https://github.com/OZI-Project/ozi-core/commit/6f90e4fda98a13f35f5df8a53ed6c80f78e6a2d0))

* build(deps): bump OZI-Project/draft from 1.0.0 to 1.0.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.0 to 1.0.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.0.0...1.0.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a774a0e`](https://github.com/OZI-Project/ozi-core/commit/a774a0ea6c8813de5852e5a88d4c7771cca84e56))

## 1.2.3 (2024-10-01)


### Bug fixes


* fix(coverage): no cover — rjdbcm <rjdbcm@outlook.com>
([`7fb3df0`](https://github.com/OZI-Project/ozi-core/commit/7fb3df0e049c905a1fa9a94e7f26436eca741b0d))

* fix(i18n): patch some missing translations — rjdbcm <rjdbcm@outlook.com>
([`5383a6f`](https://github.com/OZI-Project/ozi-core/commit/5383a6fc645e1bf9c8bec13a7c00054c5bb20f70))

## 1.2.2 (2024-10-01)


### Bug fixes


* fix: correct locale file location — rjdbcm <rjdbcm@outlook.com>
([`392d0ab`](https://github.com/OZI-Project/ozi-core/commit/392d0ab8a3d19fa0367672b799ad12078c5c6437))

## 1.2.1 (2024-10-01)


### Bug fixes


* fix(i18n): fix typechecking for Python 3.10 — rjdbcm <rjdbcm@outlook.com>
([`8d2a844`](https://github.com/OZI-Project/ozi-core/commit/8d2a844be7a0b16bd07482f2f4cc7bb3198cfcba))


### Performance improvements


* perf(mypy): type locale as str — rjdbcm <rjdbcm@outlook.com>
([`b416fc0`](https://github.com/OZI-Project/ozi-core/commit/b416fc02eaa6c5654e81544de5021615f0aedf17))

* perf: update OZI wrapfile to 1.22 — rjdbcm <rjdbcm@outlook.com>
([`8e20899`](https://github.com/OZI-Project/ozi-core/commit/8e20899ddf07d5a4085779699939188abfae41fb))

## 1.2.0 (2024-09-18)


### Features


* feat: OZI 1.22 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`6f4c7b5`](https://github.com/OZI-Project/ozi-core/commit/6f4c7b50ec756e613f2e7ed5ab6fd4227ad10517))

## 1.1.1 (2024-09-11)


### Bug fixes


* fix: package metadata download-url correction — rjdbcm <rjdbcm@outlook.com>
([`08a20ee`](https://github.com/OZI-Project/ozi-core/commit/08a20eedf26623035e15f900742a156aa1d32b18))


### Build system


* build(deps): update ozi-templates requirement from ~=2.11.1 to ~=2.12.0

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.11.1...2.12.0)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`5d57ccc`](https://github.com/OZI-Project/ozi-core/commit/5d57ccc446f36773b6f1588c280d5add8214f7f3))

* build(deps): bump step-security/harden-runner from 2.9.1 to 2.10.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.1 to 2.10.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde...91182cccc01eb5e619899d80e4e971d6181294a7)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c624d07`](https://github.com/OZI-Project/ozi-core/commit/c624d07abc4c6d83010e75ce5dafc91420ec807c))

* build(deps): update ozi-spec requirement from ~=0.9.5 to ~=0.10.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.9.5...0.10.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`04c7765`](https://github.com/OZI-Project/ozi-core/commit/04c776564057f68b81a0fbf0aec642f4cfa366af))


### Features


* feat: Merge pull request #162 from OZI-Project/dependabot/pip/ozi-templates-approx-eq-2.12.0

build(deps): update ozi-templates requirement from ~=2.11.1 to ~=2.12.0
([`efc5cb6`](https://github.com/OZI-Project/ozi-core/commit/efc5cb656ea0de930ebd2671fb493b8adab8156b))


### Performance improvements


* perf(i18n): interactive prompt and added Chinese (simplified) language support — rjdbcm <rjdbcm@outlook.com>
([`9c63941`](https://github.com/OZI-Project/ozi-core/commit/9c63941044724e49cf73e287a773a1a2b31bd3ca))


### Unknown


* :construction_worker: clean up some ``no cover`` — rjdbcm <rjdbcm@outlook.com>
([`d73e3a2`](https://github.com/OZI-Project/ozi-core/commit/d73e3a2250def23409a53aabcc2d0edc916e179e))

## 1.1.0 (2024-09-10)


### Build system


* build(deps): bump OZI-Project/checkpoint from 0.5.2 to 1.0.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.2 to 1.0.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.2...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`0dfd86e`](https://github.com/OZI-Project/ozi-core/commit/0dfd86ebddb2e456b5d5d380dd4882620971fdaa))

* build(deps): bump OZI-Project/publish from 0.1.11 to 1.0.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`b9becab`](https://github.com/OZI-Project/ozi-core/commit/b9becabfc8678be97a4850208b8b800e47e2f116))

* build(deps): bump OZI-Project/draft from 0.3.11 to 1.0.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`5c3d430`](https://github.com/OZI-Project/ozi-core/commit/5c3d430ba533a15b5a1aaffe55c495ff7af92be0))

* build(deps): bump OZI-Project/release from 0.8.11 to 1.0.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/4277e29de16b07dac4a89c8f7970c2da65554d17...98248899bb8b235e3198105f080093ea5b9751d8)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`25a7b48`](https://github.com/OZI-Project/ozi-core/commit/25a7b4826c39be079483c158a1ded00cb4583fa3))

* build(deps): update ozi-templates requirement from ~=2.10.1 to ~=2.11.1

Updates the requirements on [ozi-templates](https://github.com/OZI-Project/ozi-templates) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-templates/releases)
- [Changelog](https://github.com/OZI-Project/ozi-templates/blob/2.11.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-templates/compare/2.10.1...2.11.1)


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`8d7c41e`](https://github.com/OZI-Project/ozi-core/commit/8d7c41e05f1c082ee46d6475cb629a5c6e323a7d))


### Features


* feat: CPython 3.13 support — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`e472a59`](https://github.com/OZI-Project/ozi-core/commit/e472a59ce19cede7f47f9cd4204c4346970395cb))


### Unknown


* Update pyproject.toml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`e6fb90d`](https://github.com/OZI-Project/ozi-core/commit/e6fb90dbd92ffc0e023afa83640049636d311796))

## 1.0.12 (2024-09-06)


### Bug fixes


* fix: ozi-spec 0.9.4 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`e575dc3`](https://github.com/OZI-Project/ozi-core/commit/e575dc3992e9a54dc37f539516bd0bcb0242a862))


### Build system


* build(deps): bump OZI-Project/release from 0.8.10 to 0.8.11

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.10 to 0.8.11.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22...4277e29de16b07dac4a89c8f7970c2da65554d17)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2398784`](https://github.com/OZI-Project/ozi-core/commit/2398784d9e0a3c09e69f536b48aa8d7f22489246))

* build(deps): bump OZI-Project/draft from 0.3.10 to 0.3.11

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.10 to 0.3.11.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.10...0.3.11)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3dc7318`](https://github.com/OZI-Project/ozi-core/commit/3dc73182cd7161c6f99e419e12f91abd95eba467))

* build(pyproject.toml): remove dev dependency group — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`e8e26e8`](https://github.com/OZI-Project/ozi-core/commit/e8e26e84d97f63e59fe3c26a0370bff6b98d2fda))

* build(deps): bump OZI-Project/draft from 0.3.9 to 0.3.10

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.9 to 0.3.10.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.9...0.3.10)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d2e9b24`](https://github.com/OZI-Project/ozi-core/commit/d2e9b24da8402e4d7c260e7779c26d35885a661b))

* build(deps): bump OZI-Project/publish from 0.1.10 to 0.1.11

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.10 to 0.1.11.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.10...0.1.11)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5722ecc`](https://github.com/OZI-Project/ozi-core/commit/5722ecc8a5f4257d4c56d83a91e3d22c2cfb6086))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`2316fae`](https://github.com/OZI-Project/ozi-core/commit/2316fae4ac8a26a878328f323eee91d21fb83cfb))

## 1.0.11 (2024-09-03)


### Bug fixes


* fix: ozi-spec 0.9.3 — rjdbcm <rjdbcm@outlook.com>
([`e081118`](https://github.com/OZI-Project/ozi-core/commit/e081118d62d363d864bc31a31dd9189081a1c29d))

## 1.0.10 (2024-08-31)


### Bug fixes


* fix: create README symlink with absolute path — rjdbcm <rjdbcm@outlook.com>
([`6ca9215`](https://github.com/OZI-Project/ozi-core/commit/6ca92159c3214ae094d8daf335d47d745f6f22cb))

## 1.0.9 (2024-08-31)


### Bug fixes


* fix(ozi-fix missing): no longer check if a readme file is a symlink to detect content type — rjdbcm <rjdbcm@outlook.com>
([`7a2f052`](https://github.com/OZI-Project/ozi-core/commit/7a2f0523f2d1cb25279897db7ca46b132513faa2))

## 1.0.8 (2024-08-30)

## 1.0.7 (2024-08-30)


### Build system


* build(deps): ozi-spec~=0.9.2 — rjdbcm <rjdbcm@outlook.com>
([`94645e9`](https://github.com/OZI-Project/ozi-core/commit/94645e9b591be8315311ba89454137be1e407352))


### Performance improvements


* perf: remove type key from comment diagnostic output — rjdbcm <rjdbcm@outlook.com>
([`cb08068`](https://github.com/OZI-Project/ozi-core/commit/cb08068972823ec5e16163b8ae9619fb15aceabf))

* perf: cleaned up comment diagnostic output yaml — rjdbcm <rjdbcm@outlook.com>
([`09bfc32`](https://github.com/OZI-Project/ozi-core/commit/09bfc32d032a6b2ab1f9db1670e91fc22fad6479))

## 1.0.6 (2024-08-30)

## 1.0.5 (2024-08-30)


### Bug fixes


* fix(ozi-fix missing): rendering — rjdbcm <rjdbcm@outlook.com>
([`32e95a1`](https://github.com/OZI-Project/ozi-core/commit/32e95a1b3556c88304301011251fb4cbe43997fa))

## 1.0.4 (2024-08-30)


### Bug fixes


* fix(ozi-fix missing): README content type detection, core metadata — rjdbcm <rjdbcm@outlook.com>
([`fa8716d`](https://github.com/OZI-Project/ozi-core/commit/fa8716d83972bcc1d6e003d12612f9acd51780e6))

## 1.0.3 (2024-08-30)


### Bug fixes


* fix: README text renders — rjdbcm <rjdbcm@outlook.com>
([`60ca2f0`](https://github.com/OZI-Project/ozi-core/commit/60ca2f067ec1db949f288bda10f45531ef77f3f8))

## 1.0.2 (2024-08-30)


### Bug fixes


* fix(ozi-fix missing): classifiers now render properly — rjdbcm <rjdbcm@outlook.com>
([`c004a10`](https://github.com/OZI-Project/ozi-core/commit/c004a1014e8544fc2c8e5e50d427613afb324401))

## 1.0.1 (2024-08-30)


### Bug fixes


* fix: render METADATA for ``ozi-fix missing`` — rjdbcm <rjdbcm@outlook.com>
([`932a611`](https://github.com/OZI-Project/ozi-core/commit/932a6117416c3837b49560f9e97209f80980a473))

* fix: missing parses OZI 1.20 style dependencies — rjdbcm <rjdbcm@outlook.com>
([`55a3941`](https://github.com/OZI-Project/ozi-core/commit/55a3941cfc26cb39358e133ed5f836a989ea3ab8))


### Performance improvements


* perf: fix shadowed variable — rjdbcm <rjdbcm@outlook.com>
([`be545e5`](https://github.com/OZI-Project/ozi-core/commit/be545e5fd09b7855e5d711696470552413abc7aa))

## 1.0.0 (2024-08-29)


### Bug fixes


* fix: correct release

BREAKING CHANGE: 1.0
([`eb199c1`](https://github.com/OZI-Project/ozi-core/commit/eb199c1e98e6d38363b51e4b8a86b866eb6e2a42))

## 0.4.0 (2024-08-29)


### Bug fixes


* fix: Update pyproject.toml tox requirements install — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`c79cac8`](https://github.com/OZI-Project/ozi-core/commit/c79cac8aedd88ad0a97c9cc179743b93503de8de))

* fix: remove requirements — rjdbcm <rjdbcm@outlook.com>
([`7835209`](https://github.com/OZI-Project/ozi-core/commit/7835209bcf5c09c7171a2b5a531fcedf3fbb4f00))

* fix: remove requires-python key — rjdbcm <rjdbcm@outlook.com>
([`63aed2c`](https://github.com/OZI-Project/ozi-core/commit/63aed2c8808e936865cf24e8a3b063975041db88))

* fix: update wrapfile — rjdbcm <rjdbcm@outlook.com>
([`8470c88`](https://github.com/OZI-Project/ozi-core/commit/8470c885dd7a6aafa4e377c88f187b1b346fa8de))


### Build system


* build(deps): ozi-templates~=2.10.1 — rjdbcm <rjdbcm@outlook.com>
([`8d3db61`](https://github.com/OZI-Project/ozi-core/commit/8d3db61216deab6dd623a03ebeda754744474af2))

* build(deps): update ozi-spec requirement from ~=0.8.1 to ~=0.9.1

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.9.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.8.1...0.9.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`d570726`](https://github.com/OZI-Project/ozi-core/commit/d57072676e1f2ec2e995c3421183084208c9bffa))

* build(deps): update ozi-templates requirement from ~=2.9.3 to ~=2.10.0


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`a9548da`](https://github.com/OZI-Project/ozi-core/commit/a9548da914b3cef22eb5d1bea35aacead1ed61ea))


### Features


* feat: OZI.build 1.3 ozi-templates 2.10 ozi-spec 0.9 — rjdbcm <rjdbcm@outlook.com>
([`df99c91`](https://github.com/OZI-Project/ozi-core/commit/df99c9126bbf522e47a15cf4d6d96090390ab861))


### Performance improvements


* perf: add ``# pragma: no cover`` to previously masked untested code — rjdbcm <rjdbcm@outlook.com>
([`024c204`](https://github.com/OZI-Project/ozi-core/commit/024c2041f0c176088b76662b255cd782d99d1f80))

* perf: use main revision of OZI pre-1.20 — rjdbcm <rjdbcm@outlook.com>
([`6d81567`](https://github.com/OZI-Project/ozi-core/commit/6d81567553c83234e27e658e8b4b97955273e1a8))

* perf: add install_dependencies postconf script — rjdbcm <rjdbcm@outlook.com>
([`1c594c4`](https://github.com/OZI-Project/ozi-core/commit/1c594c450a732b3492aeff6762a05b135ffb4356))


### Unknown


* Update meson.build

BREAKING: 1.0 removes requirements.in — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`b06b8f2`](https://github.com/OZI-Project/ozi-core/commit/b06b8f2a1885b949bc9c11530c43679658c13eff))

* Update README

BREAKING: 1.0 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`41ddc46`](https://github.com/OZI-Project/ozi-core/commit/41ddc467c5d5cf20c2e96cc314094055b1ba38d7))

* :bug: remove requires-python key — rjdbcm <rjdbcm@outlook.com>
([`ef37bfa`](https://github.com/OZI-Project/ozi-core/commit/ef37bfa72bbc9747850f548bb307944a1ad6e66e))

## 0.3.1 (2024-08-23)


### Build system


* build(deps): update ozi-templates requirement from ~=2.9.0 to ~=2.9.3


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`447823d`](https://github.com/OZI-Project/ozi-core/commit/447823da26b12b16de453e9b1609943bf925d69f))

* build(deps): update ozi-spec requirement from ~=0.8.0 to ~=0.8.1

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.8.0...0.8.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`f73eed2`](https://github.com/OZI-Project/ozi-core/commit/f73eed23b0f1e28a58fc8bdf0407cfa9acf4ebb9))

## 0.3.0 (2024-08-23)


### Build system


* build(pyproject.toml): asyncio_default_fixture_loop_scope = "function" — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`6ff7990`](https://github.com/OZI-Project/ozi-core/commit/6ff7990bff16e7c3c73556951eae1c8c8e68cd42))

* build(deps): bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.1...0.5.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6a591dc`](https://github.com/OZI-Project/ozi-core/commit/6a591dc4dae5a62558034bf5e802fbe1fd8a8b52))

* build(deps): bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.8...0.3.9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`05a64a2`](https://github.com/OZI-Project/ozi-core/commit/05a64a27b40dd4f23eade8a44a38d0281cde344a))

* build(deps): bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f4172eb60419c98b5cf18c89d78cde8b553f5d15...7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f075e90`](https://github.com/OZI-Project/ozi-core/commit/f075e90baa283e316caa33942888577d60fe188f))

* build(deps): bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.9...0.1.10)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`18068af`](https://github.com/OZI-Project/ozi-core/commit/18068af36cd2b5a396e1b30ca8084edc750497a3))

* build(deps): update ozi-spec requirement from ~=0.6.1 to ~=0.8.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.6.1...0.8.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`4e0495b`](https://github.com/OZI-Project/ozi-core/commit/4e0495b87a1572f570ee7cdb93a7fe0fe358cf18))

* build(deps): update spdx-license-list requirement from ~=3.24 to ~=3.25

Updates the requirements on [spdx-license-list](https://github.com/JJMC89/spdx-license-list) to permit the latest version.
- [Release notes](https://github.com/JJMC89/spdx-license-list/releases)
- [Commits](https://github.com/JJMC89/spdx-license-list/compare/v3.24.0...v3.25.0)


updated-dependencies:
- dependency-name: spdx-license-list
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`073a707`](https://github.com/OZI-Project/ozi-core/commit/073a707fd7a89f8150f004d724cf3b2e27170d3f))


### Features


* feat(deps): ozi-templates~=2.9.0 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`54d06b7`](https://github.com/OZI-Project/ozi-core/commit/54d06b79482a85a25ba6e1cf9ff7ff5872c07edf))

* feat(deps): ozi-templates~=2.9.0 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`db49f4e`](https://github.com/OZI-Project/ozi-core/commit/db49f4e3b1bb3ebf8b260d70cbe0cac121dd37f0))

* feat(deps): ozi-templates~=2.9.0 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`e4150c1`](https://github.com/OZI-Project/ozi-core/commit/e4150c18273f41a599f06a8aad0a692f26271fe5))

## 0.2.4 (2024-08-18)


### Bug fixes


* fix: hide TAP version output during rewriter — rjdbcm <rjdbcm@outlook.com>
([`8c654e4`](https://github.com/OZI-Project/ozi-core/commit/8c654e4f94691028961dfbdc33c52bc28c55fd03))

* fix(ozi-new interactive): enable uv working — rjdbcm <rjdbcm@outlook.com>
([`8bd82b5`](https://github.com/OZI-Project/ozi-core/commit/8bd82b53ffa5bbf5ccffad8594c78d530e93cae2))


### Performance improvements


* perf: move jinja2 import to typechecking block — rjdbcm <rjdbcm@outlook.com>
([`72fef5d`](https://github.com/OZI-Project/ozi-core/commit/72fef5d5f882b41eb0a3a0909cff2edf4dec30d0))

## 0.2.3 (2024-08-18)


### Build system


* build(pyproject.toml): add uv dep — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`6bf4566`](https://github.com/OZI-Project/ozi-core/commit/6bf4566fc6595b1061ed6d03638f347e5f3016d2))


### Unknown


* :pushpin: ozi-templates~=2.8.2 — rjdbcm <rjdbcm@outlook.com>
([`bf7c319`](https://github.com/OZI-Project/ozi-core/commit/bf7c31958817b1ef8761d480e53c6e4e65eb0ce0))

## 0.2.2 (2024-08-16)


### Performance improvements


* perf: add ``--enable-uv`` argument expected in OZI spec 0.6 — rjdbcm <rjdbcm@outlook.com>
([`a2fdd6b`](https://github.com/OZI-Project/ozi-core/commit/a2fdd6bbc4c6225ca90ee1851d4e5c1180ae7272))

## 0.2.1 (2024-08-16)


### Build system


* build(deps): update ozi-spec requirement from ~=0.5.10 to ~=0.6.1

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.5.10...0.6.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`7e69af3`](https://github.com/OZI-Project/ozi-core/commit/7e69af3d275247695b1d2bb0ab6984c002ea6fdc))

* build(deps): update ozi-templates requirement from ~=2.7.1 to ~=2.8.0


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`137af6b`](https://github.com/OZI-Project/ozi-core/commit/137af6b59d728f5f462b82073f75e05b887ae015))

## 0.2.0 (2024-08-15)


### Features


* feat: OZI-Templates 2.7

GitHub workflows are no longer hardened by default.
Wheels are now built with release 0.8 which can build extension wheels! — rjdbcm <rjdbcm@outlook.com>
([`607b555`](https://github.com/OZI-Project/ozi-core/commit/607b555d1c638551853ef7b6372bdff919769f4d))


### Unknown


* :rotating_light: run black — rjdbcm <rjdbcm@outlook.com>
([`bfe1b1b`](https://github.com/OZI-Project/ozi-core/commit/bfe1b1bf43c6dedf9b87ca74fe53b804e7f6ab34))

## 0.1.21 (2024-08-12)


### Performance improvements


* perf: TAP-Producer~=1.0.4 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`9ab7475`](https://github.com/OZI-Project/ozi-core/commit/9ab7475350b47e96de48efa7ccb40dd5a6fd3721))

## 0.1.20 (2024-08-12)


### Bug fixes


* fix: OZI-Project/release@0.8.9 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`24a04fc`](https://github.com/OZI-Project/ozi-core/commit/24a04fc6443fc65cae87513faf49907ae42ea276))

* fix: update release workflow — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`2be9889`](https://github.com/OZI-Project/ozi-core/commit/2be98899a9c31cd141fbe2b4d18782c0ce8f0caa))


### Build system


* build(deps): bump OZI-Project/release from 0.8.5 to 0.8.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.5 to 0.8.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.5...0.8.7)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8575198`](https://github.com/OZI-Project/ozi-core/commit/85751987f1493d01d43106563162a575bedb473d))

* build(deps): update ozi-templates requirement from ~=2.6.1 to ~=2.6.4


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`d3d5cb0`](https://github.com/OZI-Project/ozi-core/commit/d3d5cb05694abf0d50833b89781558579a92cc4d))

## 0.1.19 (2024-08-12)


### Bug fixes


* fix: patch trigger — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`f175b58`](https://github.com/OZI-Project/ozi-core/commit/f175b58256581e6c8dd3f061eb4fecb7162833db))


### Performance improvements


* perf: run lint
([`7bf2d0a`](https://github.com/OZI-Project/ozi-core/commit/7bf2d0abac0288f193c6dff1877d7caab02172df))


### Unknown


* :children_crossing: clean up diagnostic outputs — rjdbcm <rjdbcm@outlook.com>
([`e2ae6bd`](https://github.com/OZI-Project/ozi-core/commit/e2ae6bdbadf9fa38c61bcd101dbf0e7f7240bfa3))

## 0.1.18 (2024-08-11)


### Bug fixes


* fix(ozi-new): set TAP.version before parsing args — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`4ce1d1c`](https://github.com/OZI-Project/ozi-core/commit/4ce1d1c055ac3b5c4ac852382325ae73453ac834))


### Build system


* build: update ozi.yml allowed endpoints — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`3ee473d`](https://github.com/OZI-Project/ozi-core/commit/3ee473d61f7fc6c8246af013b5b7693d5b736587))

* build(deps): bump OZI-Project/release from 0.7.4 to 0.8.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.4 to 0.8.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.4...0.8.5)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d78bc4a`](https://github.com/OZI-Project/ozi-core/commit/d78bc4ab30aebaad18cca25531c7f1fe300100c4))

## 0.1.17 (2024-08-07)


### Build system


* build(deps): update ozi-templates requirement from ~=2.5.8 to ~=2.6.1


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`87a7da5`](https://github.com/OZI-Project/ozi-core/commit/87a7da50ea70f596e277469538dfb73113a1f4ef))

## 0.1.16 (2024-08-07)


### Build system


* build(deps): update tap-producer requirement from ~=0.2 to ~=1.0

Updates the requirements on [tap-producer](https://github.com/OZI-Project/TAP-Producer) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/TAP-Producer/releases)
- [Changelog](https://github.com/OZI-Project/TAP-Producer/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/TAP-Producer/compare/0.2.0...1.0.0)


updated-dependencies:
- dependency-name: tap-producer
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`f122071`](https://github.com/OZI-Project/ozi-core/commit/f1220712a2763fde9d562fee76cd4eebdd7dcd87))

* build(deps): update ozi-spec requirement from ~=0.5.8 to ~=0.5.9

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.5.9/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.5.8...0.5.9)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`caae3de`](https://github.com/OZI-Project/ozi-core/commit/caae3de352cd02488393e5a88aeee45a1c824137))

* build(deps): bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.0...0.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2b5c025`](https://github.com/OZI-Project/ozi-core/commit/2b5c02551ff2e40ad6fd48cb998819c0513b66dd))

* build(deps): bump OZI-Project/release from 0.7.3 to 0.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.3...0.7.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9a2de2f`](https://github.com/OZI-Project/ozi-core/commit/9a2de2f6274362809ac0c63f2c472f44eeec867d))

* build(deps): bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3365971`](https://github.com/OZI-Project/ozi-core/commit/3365971d93c97a895be9478e958729bed73378dc))

* build(deps): bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.7...0.3.8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`04aa4b1`](https://github.com/OZI-Project/ozi-core/commit/04aa4b15977ebc84bd6a98bbee98e42dd1f4594a))

* build: Update pyproject.toml:tool.semantic_release.commit_parser_options.patch_tags add build — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`553efa8`](https://github.com/OZI-Project/ozi-core/commit/553efa89fb9426e101a65d6a32d9fc39a48d15d8))

* build(deps): update ozi-templates requirement from ~=2.5.6 to ~=2.5.8


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`d937739`](https://github.com/OZI-Project/ozi-core/commit/d9377391f26d9a2234b16d6fc9895c2fdb29cccc))


### Performance improvements


* perf: refactor interactive submodule — rjdbcm <rjdbcm@outlook.com>
([`1d13d8e`](https://github.com/OZI-Project/ozi-core/commit/1d13d8e594ce2121f811462bed5bc4d05e7757ad))

## 0.1.15 (2024-07-30)


### Build system


* build(deps): update ozi-spec requirement from ~=0.5.7 to ~=0.5.8

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.5.7...0.5.8)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`87a9703`](https://github.com/OZI-Project/ozi-core/commit/87a970368906f23468e0dce658f3b95d9fe4856d))


### Performance improvements


* perf: Merge pull request #50 from OZI-Project/main

Release
([`7286ba3`](https://github.com/OZI-Project/ozi-core/commit/7286ba3a407aee2821624f78a8e45793c7147f58))

## 0.1.14 (2024-07-29)


### Performance improvements


* perf: TAP-Producer~=0.2 — rjdbcm <rjdbcm@outlook.com>
([`806e4e6`](https://github.com/OZI-Project/ozi-core/commit/806e4e690f036834aa5f2d79c9b2eb6c027f0462))

* perf: ozi-spec~=0.5.7 — rjdbcm <rjdbcm@outlook.com>
([`25905f1`](https://github.com/OZI-Project/ozi-core/commit/25905f119deb214f69ece76753f56386f6715e77))

* perf: use TAP version 14 in ``ozi-new`` and ``ozi-fix`` — rjdbcm <rjdbcm@outlook.com>
([`4e65ef5`](https://github.com/OZI-Project/ozi-core/commit/4e65ef546af4472125add85e2a4f987a38813526))

## 0.1.13 (2024-07-28)


### Bug fixes


* fix: gitpython~=3.1 — rjdbcm <rjdbcm@outlook.com>
([`fd822c6`](https://github.com/OZI-Project/ozi-core/commit/fd822c640c0b469e71d46ea7f279a8b5cb42ae88))

## 0.1.12 (2024-07-25)


### Bug fixes


* fix(requirements.in): ozi-spec~=0.5.7 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`2aa4a87`](https://github.com/OZI-Project/ozi-core/commit/2aa4a87cedecb07bf0e68f0f19b9131269ddf2e7))

## 0.1.11 (2024-07-25)


### Build system


* build(deps): bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.8...0.1.9)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`452ad21`](https://github.com/OZI-Project/ozi-core/commit/452ad214b47668d8dd6112a2e51d1029b32624a6))

* build(deps): bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.6...0.3.7)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`905c8dd`](https://github.com/OZI-Project/ozi-core/commit/905c8ddb2294e12d17db0ff8c8763c15746e6f5f))

## 0.1.10 (2024-07-22)


### Build system


* build(deps): update tap-producer requirement from ~=0.1.4 to ~=0.2.0

Updates the requirements on [tap-producer](https://github.com/OZI-Project/TAP-Producer) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/TAP-Producer/releases)
- [Changelog](https://github.com/OZI-Project/TAP-Producer/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/TAP-Producer/compare/0.1.4...0.2.0)


updated-dependencies:
- dependency-name: tap-producer
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`31f6262`](https://github.com/OZI-Project/ozi-core/commit/31f626294d42088b072aa00704c14af2a4d06d39))

## 0.1.9 (2024-07-19)

## 0.1.8 (2024-07-19)

## 0.1.7 (2024-07-19)


### Bug fixes


* fix: use ``ozi.version`` as key for wrapfile release revision selection — rjdbcm <rjdbcm@outlook.com>
([`708552c`](https://github.com/OZI-Project/ozi-core/commit/708552cf3928b49393f8443c11659e8db71ba093))

* fix: move remaining core functionality to package — rjdbcm <rjdbcm@outlook.com>
([`0bb22a3`](https://github.com/OZI-Project/ozi-core/commit/0bb22a3efa9022386155a8cf3626e89429552a3a))

* fix: ozi-core~=0.5.6 — rjdbcm <rjdbcm@outlook.com>
([`485227f`](https://github.com/OZI-Project/ozi-core/commit/485227fc49d271ff8d946fc3cff33c4555c40f8e))

* fix: correct changelog title — rjdbcm <rjdbcm@outlook.com>
([`a01e5ce`](https://github.com/OZI-Project/ozi-core/commit/a01e5ceb1f51e084ceb4bc49bd15f08de8dd450c))

* fix: correct ``templates/templates/*`` names to include ``.j2`` extension — rjdbcm <rjdbcm@outlook.com>
([`ba9a68d`](https://github.com/OZI-Project/ozi-core/commit/ba9a68d5bfaba9513af8480fcc604527211de017))

* fix: ozi-spec~=0.5.5

Implements sigstore-v3 workflows. — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`a2b2eac`](https://github.com/OZI-Project/ozi-core/commit/a2b2eacb4113d711077724c8b9ceced4071ac6f6))

* fix: ozi-spec~=0.5.4 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`dc31546`](https://github.com/OZI-Project/ozi-core/commit/dc31546e5e1714f823535edceb8ee70ba6cbb60e))


### Build system


* build(deps): bump step-security/harden-runner from 2.8.0 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/v2.8.0...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`bef7e1e`](https://github.com/OZI-Project/ozi-core/commit/bef7e1e2b0fcb9656f28171f316296a2834a5c54))

* build(deps): update packaging requirement from ~=24.0 to ~=24.1

Updates the requirements on [packaging](https://github.com/pypa/packaging) to permit the latest version.
- [Release notes](https://github.com/pypa/packaging/releases)
- [Changelog](https://github.com/pypa/packaging/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pypa/packaging/compare/24.0...24.1)


updated-dependencies:
- dependency-name: packaging
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`13daef7`](https://github.com/OZI-Project/ozi-core/commit/13daef726f2bc916734e06bfb59d9940247ac1cd))

* build(deps): bump OZI-Project/release from 0.6.5 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.5 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.5...0.7.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a82c406`](https://github.com/OZI-Project/ozi-core/commit/a82c40631ffb94899420873b0cdf6c4914e0a73d))

* build(deps): bump OZI-Project/publish from 0.1.7 to 0.1.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.7 to 0.1.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.7...0.1.8)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`152e647`](https://github.com/OZI-Project/ozi-core/commit/152e647612924699180b78034eceb99bad2798cf))

* build(deps): bump OZI-Project/draft from 0.3.4 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.4 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.4...0.3.6)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e60538c`](https://github.com/OZI-Project/ozi-core/commit/e60538c29ac5d1f618f259cf2d7c7629cd574759))

* build(deps): bump OZI-Project/checkpoint from 0.4.2 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.2 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.2...0.5.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a3c014a`](https://github.com/OZI-Project/ozi-core/commit/a3c014aa8c0d41374a1ebea87892433459a0e6b3))

* build(deps): update tap-producer requirement from ~=0.1.1 to ~=0.1.4

Updates the requirements on [tap-producer](https://github.com/OZI-Project/TAP-Producer) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/TAP-Producer/releases)
- [Changelog](https://github.com/OZI-Project/TAP-Producer/blob/0.1.4/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/TAP-Producer/compare/0.1.1...0.1.4)


updated-dependencies:
- dependency-name: tap-producer
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`aa61e25`](https://github.com/OZI-Project/ozi-core/commit/aa61e259ba90382d99881afd96ac425a2a42b47b))

* build(deps): ozi-templates~=2.5.5 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`d867913`](https://github.com/OZI-Project/ozi-core/commit/d8679132219753a12f47e57411a221d4a95d310b))


### Performance improvements


* perf: Merge pull request #23 from OZI-Project/patch/sigstore-v3

Patch/sigstore v3
([`b63fd5b`](https://github.com/OZI-Project/ozi-core/commit/b63fd5b6de42e0f17b163f1fd9f1d3f74d20d7be))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`d0784c5`](https://github.com/OZI-Project/ozi-core/commit/d0784c5dfe89852a42a3ac2e04af6bce165ff536))

* Create dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`e810ff4`](https://github.com/OZI-Project/ozi-core/commit/e810ff42fdec165967f31a39f9e14bbb6814c41e))

## 0.1.6 (2024-07-18)


### Bug fixes


* fix: OZI.build>=0.0.27 — rjdbcm <rjdbcm@outlook.com>
([`bc032f2`](https://github.com/OZI-Project/ozi-core/commit/bc032f214fc8cdfa51f6748b8f07461e301cf686))

## 0.1.5 (2024-07-18)


### Bug fixes


* fix: ozi-spec~=0.5.2 — rjdbcm <rjdbcm@outlook.com>
([`bf4a290`](https://github.com/OZI-Project/ozi-core/commit/bf4a2903a4b7fd9d8d42570e6a3ca69c2ece1af9))

## 0.1.4 (2024-07-12)


### Bug fixes


* fix: ozi missing parser accepts target — rjdbcm <rjdbcm@outlook.com>
([`0b6892c`](https://github.com/OZI-Project/ozi-core/commit/0b6892cbf9d8d1c174402746c419aa844e5cc3ab))


### Performance improvements


* perf: clean up imports
([`f993ee4`](https://github.com/OZI-Project/ozi-core/commit/f993ee46db3d06b8c62d3163b0d384d53f2723ca))

## 0.1.3 (2024-07-12)


### Performance improvements


* perf: run black — rjdbcm <rjdbcm@outlook.com>
([`0728216`](https://github.com/OZI-Project/ozi-core/commit/0728216e7c48e8bd30872d56911328241121ea19))

## 0.1.2 (2024-07-12)

## 0.1.1 (2024-07-11)


### Bug fixes


* fix: comment scoring is fixed
([`bdc4b60`](https://github.com/OZI-Project/ozi-core/commit/bdc4b60d2b90b01e412f1dbde12b6287b43da5cf))

* fix: fix comment line counting — rjdbcm <rjdbcm@outlook.com>
([`d2d0192`](https://github.com/OZI-Project/ozi-core/commit/d2d019276f49bddae27fc752312ed9ed144f68a7))

* fix(ozi.fix.parser): target as final argument — rjdbcm <rjdbcm@outlook.com>
([`3afe42f`](https://github.com/OZI-Project/ozi-core/commit/3afe42f3bde8113f53b8f87aeb8cc49645375051))

## 0.1.0 (2024-07-11)

## 0.0.2 (2024-07-11)

## 0.0.1 (2024-07-11)


### Bug fixes


* fix: override version arg for ``actions.info`` — rjdbcm <rjdbcm@outlook.com>
([`dcb0b8f`](https://github.com/OZI-Project/ozi-core/commit/dcb0b8f8eeb6eacf05910eb8e461c0f1114ac5fb))

* fix(ozi_core.fix.parser): target always last argument — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`52a135a`](https://github.com/OZI-Project/ozi-core/commit/52a135a3806af39bc30b5cf66461995fe6bd3af8))

* fix(ozi_core.new.parser): target now the last argument — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`92f8b86`](https://github.com/OZI-Project/ozi-core/commit/92f8b868f23778c835f522b64730819eaf48c97e))

* fix(requirements.in): add ``prompt-toolkit`` — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`f5ccb78`](https://github.com/OZI-Project/ozi-core/commit/f5ccb78f3e1f6165052b25635c85564219cc0315))


### Features


* feat: remove ``print_version`` and add version arg to ``check_version`` — rjdbcm <rjdbcm@outlook.com>
([`d88a200`](https://github.com/OZI-Project/ozi-core/commit/d88a2008163c244b56ffffdacb0727ca0d039f85))

## 0.0.0 (2024-07-10)


### Unknown


* init
([`fc288f5`](https://github.com/OZI-Project/ozi-core/commit/fc288f56d4e0f31b3e4150ec4d6829df61ac117c))



## 0.0.0 (2024-07-09)

### :tada:

* :tada:: Initialized ozi-core with ``ozi-new``.

```sh
ozi-new project --name ozi-core --summary 'The OZI Project packaging core library.' --keywords OZI,mesonbuild --home-page https://www.oziproject.dev --author 'Eden Ross Duff MSc' --author-email help@oziproject.dev --license 'OSI Approved :: Apache Software License' --license-expression 'Apache-2.0 WITH LLVM-exception' --requires-dist 'pyparsing~=3.1' --requires-dist 'GitPython>=3' --requires-dist 'TAP-Producer~=0.1.1' --requires-dist 'meson[ninja]>=1.1.0' --requires-dist requests --requires-dist types-requests --requires-dist 'packaging~=24.0' --requires-dist spdx-license-list --requires-dist 'ozi-spec~=0.5' --requires-dist 'ozi-templates~=2.5.1'
```
